<?php

/**
 * Fired during plugin activation
 *
 * @link       https://aonetheme.com/
 * @since      1.0.0
 *
 * @package    Appointy
 * @subpackage Appointy/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Appointy
 * @subpackage Appointy/includes
 * @author     Aone Team <aonetheme@gmail.com>
 */
class Appointy_Activator {

	/**
	 * Fired during plugin activation.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
		
		/**
         * Custom Post Types
         */
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-appointy-post-types.php';
		
        $appointy_post_types = new Appointy_Post_Types();
		
		$appointy_post_types->create_custom_post_type();
		
		flush_rewrite_rules();
		
		/**
         * Add staff member role
         */
		add_role(
			 'appointy_staff',
			 __('Staff', 'appointy'), 
			 array( 
				  'read' => true,
				  'edit_posts' => true,
				  'edit_other_posts' => true,
				  'edit_published_posts' => true
			 )
		);
		
		/**
         * Add staff member role
         */
		add_role(
			 'appointy_customer',
			 __('Customer', 'appointy'), 
			 array( 
				  'read' => true,
				  'edit_posts' => true,
				  'edit_other_posts' => true,
				  'edit_published_posts' => true
			 )
		);
		
		/**
         *  Register and use custom tables in database
         */
		self::create_db();
		self::create_default_pages();
		self::schedule_cronjobs();
		
		add_option('plugin_needs_verification', true);
	}
	
	/**
	 *  Define Schedule cronjobs
	 */
	public static function schedule_cronjobs() {
		/*Cron job for featured expire*/
		if ( !wp_next_scheduled( 'fetch_gc_events' ) ){
			wp_schedule_event( time(), 'daily', 'fetch_gc_events' );
		}
		/*Cron job for activate repeat service*/
		if ( !wp_next_scheduled( 'activate_repeat_service' ) ){
			wp_schedule_event( time(), 'daily', 'activate_repeat_service' );
		}
	}
	
	/**
	 *  Define function for register and use custom tables in database
	 */
	public static function create_db() {
		global $wpdb;
		
		$appointy_db_version = get_option( 'appointy_db_version', '1.0' );
	
		
	
			$charset_collate = $wpdb->get_charset_collate();
	
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_work_periods (
				`id` mediumint(9) NOT NULL AUTO_INCREMENT,
				`member_id` int(11),
				`start_time` time,
				`end_time` time,
				`start_time_number` smallint(6),
				`end_time_number` smallint(6),
				`weekday` varchar(128),
				`weekday_number` tinyint(3),
				`interval` tinyint(11),
				`custom_date` date,
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_blocked_schedule (
				`id` mediumint (11) NOT NULL AUTO_INCREMENT,
				`member_id` int(11),
				`branch_id` int(11),
				`service_id` int(11),
				`appointment_id` int (11),
				`repeat_service_id` int(11),
				`dayoff_type` varchar (128),
				`date` date,
				`day` varchar (128),
				`start_date` date,
				`end_date` date,
				`start_time` time,
				`end_time` time,
				`start_time_number` smallint(6),
				`end_time_number` smallint(6),
				`type` varchar (128),
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_repeat_schedule (
				`id` mediumint (11) NOT NULL AUTO_INCREMENT,
				`appointment_id` int (11),
				`service_id` int (11),
				`frequency` varchar (128),
				`selected_weekday` int(11),
				`day_of_month` int(11),
				`num_times` int(11),
				`date` date,
				`start_time` time,
				`end_time` time,
				`status` varchar(128),
				`payment_status` varchar(128),
				`service_price` decimal(10,2) not null default 0.00,
				`extra_service_total` decimal(10,2) not null default 0.00,
				`tax_amount` decimal(10,2) not null default 0.00,
				`total_amount` decimal(10,2) not null default 0.00,
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_extra_services (
				`id` mediumint (11) NOT NULL AUTO_INCREMENT,
				`appointment_id` int (11),
				`service_id` int (11),
				`extra_service_id` int (11),
				`type` varchar (128),
				`extra_service_name` varchar (128),
				`extra_service_unit_price` decimal(10,2) not null default 0.00,
				`extra_service_quantity` int (11),
				`extra_service_price` decimal(10,2) not null default 0.00,
				`hours` int(11),
				`minutes` int(11),
				`display_service_period` varchar(128) default '',
				`service_period` int(11),
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_multiple_dates (
				`id` mediumint (11) NOT NULL AUTO_INCREMENT,
				`appointment_id` int (11),
				`service_id` int (11),
				`date` date,
				`time` time,
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "services (
				`id` mediumint(9) NOT NULL AUTO_INCREMENT,
				`service_id` int(11),
				`service_title` text,
				`description` longtext,
				`category` varchar(200),
				`childcategory` varchar(200),
				`hourly_service` varchar(200),
				`price` decimal(10,2) not null default 0.00,
				PRIMARY KEY  (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_taxes (
				`id` mediumint(9) NOT NULL AUTO_INCREMENT,
				`tax_name` text,
				`tax` decimal(10,2) not null default 0.00,
				`tax_type` varchar(128),
				`services` longtext,
				`status` varchar(128),
				PRIMARY KEY  (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_booked_services (
				`id` mediumint(9) NOT NULL AUTO_INCREMENT,
				`date` datetime default '0000-00-00 00:00:00' NOT NULL,
				`appointment_id` int(11),
				`has_repeat` varchar(128),
				`repeat_service_id` int(11),
				`repeat_service_payment` varchar(128),
				`service_id` int(11),
				`service_name` varchar(128),
				`bookingtype` varchar(128),
				`servicetype` varchar(128),
				`service_period` int(11),
				`variation_name` varchar(128),
				`hours` int(11),
				`minutes` int(11),
				`display_service_period` varchar(128) default '',
				`show_branches` varchar(128) default '',
				`members_available` varchar(128) default '',
				`branch_id` int(11),
				`member_id` int(11),
				`booking_date` date,
				`booking_start_time` time,
				`booking_end_time` time,
				`booking_start_date` date,
				`booking_end_date` date,
				`rooms` int(11),
				`adults` int(11),
				`children` int(11),
				`parent_category` int(11),
				`service_status` varchar(128) default 'pending',
				`status_update_by` varchar(128) default '',
				`service_price` decimal(10,2) not null default 0.00,
				`booking_amount_status` varchar(128) default '',
				`customerid` int(11),
				`customeremail` varchar(128) default '',
				`couponcode` varchar(128) default '',
				`oldserviceprice` varchar(128) default '',
				`cacellation_reason` longtext,
				`google_calendar_url` longtext,
				`google_calendar_event_id` varchar(128) default '',
				`customer_google_calendar_url` longtext,
				`customer_google_calendar_event_id` varchar(128) default '',
				`admin_google_calendar_url` longtext,
				`admin_google_calendar_event_id` varchar(128) default '',
				`service_completed_date` date,
				`multidate_service` varchar(128) default '',
				`multidate_service_type` varchar(128) default '',
				`number_of_dates` int(11),
				`fullday_timeslots` varchar(128) default '',
				PRIMARY KEY  (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_notifications (
				`id` mediumint(9) NOT NULL AUTO_INCREMENT,
				`datetime` datetime DEFAULT NULL,
				`admin_id` BIGINT(20) UNSIGNED,
				`customer_id` BIGINT(20) UNSIGNED,
				`title` text,
				`description` longtext,
				`link` VARCHAR(255) DEFAULT NULL,
				`reference` VARCHAR(255) DEFAULT NULL,
				`reference_id` BIGINT(20) UNSIGNED,
				`action_perform_by` BIGINT(20) UNSIGNED,
				`status` VARCHAR(200) DEFAULT 'unread',
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_zoom_meetings (
				`id` mediumint(9) NOT NULL AUTO_INCREMENT,
				`appointment_id` int(11),
				`appointment_service_id` int(11),
				`room_title` VARCHAR(128) DEFAULT NULL,
				`meeting_id` BIGINT(20) UNSIGNED,
				`host_url` longtext,
				`join_url` longtext,
				`meeting_details` longtext,
				`room_password` VARCHAR(128) DEFAULT NULL,
				`class_start_time` datetime DEFAULT NULL,
				`created_by` VARCHAR(128) DEFAULT NULL,
				`duration` BIGINT(20) UNSIGNED,
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_permissions (
				id int(9) NOT NULL AUTO_INCREMENT,
				action varchar(128),
				admin varchar(128),
				member varchar(128),
				customer varchar(128),
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_service_location_satff (
				id int(9) NOT NULL AUTO_INCREMENT,
				service_id int(11),
				location_id int(11),
				staff_id int(11),
				PRIMARY KEY (id)
			) $charset_collate;";
			
			$sqls[] = "CREATE TABLE " . $wpdb->prefix . "appointy_service_location_prices (
				id int(9) NOT NULL AUTO_INCREMENT,
				service_id int(11),
				variation_id int(11),
				service_type varchar(128),
				location_id int(11),
				sale_price decimal(10,2) not null default 0.00,
				regular_price decimal(10,2) not null default 0.00,
				final_price decimal(10,2) not null default 0.00,
				PRIMARY KEY (id)
			) $charset_collate;";
			
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	
			foreach($sqls as $sql){
				dbDelta( $sql );
			} 
			
			add_option( 'appointy_db_version', $appointy_db_version );
	
		
	
	}
	
	/**
	 *  Create default pages required for plugin
	 */
	public static function create_default_pages() {
		
		if((bool) post_exists('Appointment Form') == 0){
			wp_insert_post(array(
				'post_title' => 'Appointment Form',
				'post_content' => '[appointy-booking-form]',
				'post_status' => 'publish',
				'post_type' => 'page',
				'page_template' => 'template-appointy'
			));
		}
		
		if((bool) post_exists('Customer Dashboard') == 0){
			wp_insert_post(array(
				'post_title' => 'Customer Dashboard',
				'post_content' => '[appointy-customer-dashboard]',
				'post_status' => 'publish',
				'post_type' => 'page',
				'page_template' => 'template-appointy'
			));
		}
		
		if((bool) post_exists('Staff Dashboard') == 0){
			wp_insert_post(array(
				'post_title' => 'Staff Dashboard',
				'post_content' => '[appointy-staff-dashboard]',
				'post_status' => 'publish',
				'post_type' => 'page',
				'page_template' => 'template-appointy'
			));
		}
		
		if ((bool) post_exists('Appointy Invoice Payment') === false) {
			wp_insert_post(array(
				'post_title' => 'Appointy Invoice Payment',
				'post_content' => '[appointy-invoice-pay]',
				'post_status' => 'publish',
				'post_type' => 'page',
			));
		}
		
		if ((bool) post_exists('Appointy Thank You') === false) {
			wp_insert_post(array(
				'post_title' => 'Appointy Thank You',
				'post_content' => '[appointy-thank-you]',
				'post_status' => 'publish',
				'post_type' => 'page',
			));
		}
		
		if ((bool) post_exists('Appointy Login') === false) {
			wp_insert_post(array(
				'post_title' => 'Appointy Login',
				'post_content' => '[appointy-login]',
				'post_status' => 'publish',
				'post_type' => 'page',
			));
		}
		
		ob_get_clean();
	}
}
