<?php
defined('ABSPATH') or die("Direct access to the script does not allowed");

/**
 * Handle AJAX calls
 */
class Appointy_Admin_Ajax
{

    /**
     * Instance of this class.
     *
     * @since    1.0.0
     *
     * @var      object
     */
    protected static $instance = null;

    /**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		add_action('wp_ajax_save_service_category', array($this, 'save_service_category'));
		add_action('wp_ajax_load_states_terms_ids', array($this, 'load_states_terms_ids'));
		
    }
	

    /**
     * Return an instance of this class.
     *
     * @since     1.0.0
     *
     * @return    object    A single instance of this class.
     */
    public static function get_instance()
    {

        // If the single instance hasn't been set, set it now.
        if (null === self::$instance) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    /**
     * Save service category
     *
     * @since    1.0.0
     */
    public function save_service_category() {

        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) || !current_user_can('manage_options') ) {
			wp_send_json_error();
			die();
		}
		
        $taxonomy = 'appointy_service_category';
		
		$title = Appointy_Router_Helper::get_sanitize_data($_POST['service_category'],'name');
		$description = Appointy_Router_Helper::get_sanitize_data($_POST['service_category'],'description');
		$image_id = Appointy_Router_Helper::get_sanitize_data($_POST['service_category'],'image_id');

		$termexists = term_exists( $title, $taxonomy );
		$termid = 0;
		if ( $termexists !== 0 && $termexists !== null ) {
			$termid = (!empty($termexists['term_id'])) ? $termexists['term_id'] : 0;
			
			$response = array( 'msg' => esc_html__('Service category already exists.', 'appointy') );
			wp_send_json_error($response);
			exit;
		}else{
			$args = array(
						'description' => $description
					);
			$term = wp_insert_term( $title, $taxonomy, $args );
		
			if(!is_wp_error( $term )){
				$termid = (!empty($term['term_id'])) ? Appointy_Router_Helper::get_sanitize_data($term,'term_id') : 0;
				
				update_term_meta($termid,'image_id',$image_id);
			}else{
				$response = array('msg' => $term->get_error_message());
				wp_send_json_error($response);
				exit;
			}
		}

		$response = array( 'msg' => esc_html__('Service category has saved.', 'appointy') );
        wp_send_json_success($response);
        die();
    }
	
	/**
	 * Process load state terms
	 *
	 * @return array
	 */
	public static function load_states_terms_ids( ) {
		global $wpdb;
		extract($_POST);
		
		$default_country_id = Appointy_Router_Helper::get_request_data( $_POST, 'country' );
		
		$has_state = false;
		
		$texonomy = 'appointy_state';
		$args = array(
				'orderby'           => 'name',
				'order'             => 'ASC',
				'hide_empty'        => false
			); 
		$states = get_terms( $texonomy,$args );
		
		$option = '';
		if(!empty($states) && !empty($country))
		{
			$option .= '<option value="">'.sprintf( esc_html__( 'Choose %s', 'appointy' ), Appointy_Location_Helper::get_state_replacement( 'singular' ) ).'</option>';
			foreach($states as $term)
			{
				$country_id = get_term_meta($term->term_id, 'country', true);
				if($country_id === $default_country_id) {
					$has_state = true;
					$option .= '<option value="'.$term->term_id.'">'.$term->name.'</option>';		
				}
			}
		}
		
		if( $has_state === true ) {
			wp_send_json_success($option);
		} else {
			$option = '<option value="">'.esc_html__( 'Not available', 'appointy' ).'</option>';
			wp_send_json_success($option);
		}
		die();
	}
	
}