<?php



/**

 * The file that defines the core plugin class

 *

 * A class definition that includes attributes and functions used across both the

 * public-facing side of the site and the admin area.

 *

 * @link       https://aonetheme.com/

 * @since      1.0.0

 *

 * @package    Appointy

 * @subpackage Appointy/includes

 */



/**

 * The core plugin class.

 *

 * This is used to define internationalization, admin-specific hooks, and

 * public-facing site hooks.

 *

 * Also maintains the unique identifier of this plugin as well as the current

 * version of the plugin.

 *

 * @since      1.0.0

 * @package    Appointy

 * @subpackage Appointy/includes

 * @author     Aone Team <aonetheme@gmail.com>

 */

class Appointy {



	/**

	 * The loader that's responsible for maintaining and registering all hooks that power

	 * the plugin.

	 *

	 * @since    1.0.0

	 * @access   protected

	 * @var      Appointy_Loader    $loader    Maintains and registers all hooks for the plugin.

	 */

	protected $loader;



	/**

	 * The unique identifier of this plugin.

	 *

	 * @since    1.0.0

	 * @access   protected

	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.

	 */

	protected $plugin_name;

	

	/**

	 * The current version of the plugin.

	 *

	 * @since    1.0.0

	 * @access   protected

	 * @var      string    $version    The current version of the plugin.

	 */

	protected $version;



	/**

	 * Define the core functionality of the plugin.

	 *

	 * Set the plugin name and the plugin version that can be used throughout the plugin.

	 * Load the dependencies, define the locale, and set the hooks for the admin area and

	 * the public-facing side of the site.

	 *

	 * @since    1.0.0

	 */

	 

	/**

	 * Plugin path.

	 *

	 * @var string

	 */

	private $plugin_path;



	/**

	 * WordPress Settings Framework instance.

	 *

	 * @var WordPressSettingsFramework

	 */

	private $wpsf;

	 

	public function __construct() {

		

		$this->plugin_path = plugin_dir_path( __FILE__ );

		

		if ( defined( 'APPOINTY_VERSION' ) ) {

			$this->version = APPOINTY_VERSION;

		} else {

			$this->version = '1.0.0';

		}

		$this->plugin_name = 'appointy';



		$this->load_dependencies();

		$this->set_locale();

		$this->define_admin_hooks();

		$this->define_public_hooks();

		

		// Include and create a new WordPressSettingsFramework.

		require_once APPOINTY_PLUGIN_DIR . 'library/settings-framework/settings-framework.php';

		$this->wpsf = new WordPressSettingsFramework( APPOINTY_PLUGIN_DIR . 'settings/appointy-settings.php', 'appointy' );



		// Add admin menu.

		add_action( 'admin_menu', array( $this, 'add_settings_page' ), 20 );



		// Add an optional settings validation filter (recommended).

		add_filter( $this->wpsf->get_option_group() . '_settings_validate', array( $this, 'validate_settings' ) );

		

		add_filter( 'theme_page_templates', array( $this, 'appointy_page_templates' ), 99 );

		

		add_filter( 'template_include', array( $this, 'appointy_change_page_template' ), 99 );

		

		add_action( 'after_setup_theme', array( $this, 'appointy_add_image_sizes' ), 99 );

		

		define( 'APPOINTY_BOOKING_TYPE', Appointy_Misc_Helper::get_settings( 'booking_settings', 'booking_type', 'general' ) );

		

	}

	

	/**

	 * Add image sizes

	 */

	public function appointy_add_image_sizes( $templates ) {

		add_image_size( 'appointy-300x300', 300, 300, true );

	}

	

	

	/**

	 * Load new page template

	 */

	public function appointy_page_templates( $templates ) {

		$templates['template-appointy'] = esc_html__('Appointy Template', 'appointy');



		return $templates;	

	}

	

	/**

	 * Save page template

	 */

	public function appointy_change_page_template( $templates = '' ) {

		

		$user_selected_template = get_page_template_slug(get_the_ID());

		

		if($user_selected_template === 'template-appointy') {

			$templates = APPOINTY_PLUGIN_DIR . 'templates/template-appointy.php';

		}



        return $templates;

	}

	

	

	/**

	 * Add settings page.

	 */

	

	/**

	 * Add settings page.

	 */

	public function add_settings_page() {

		$this->wpsf->add_settings_page(

			array(

				'parent_slug' => 'appointment',

				'page_title'  => esc_html__('Appointment Settings', 'appointy'),

				'menu_title'  => esc_html__('Settings', 'appointy'),

				'capability'  => 'manage_options'

			)

		);

	}

	

	/**

	 * Validate settings.

	 *

	 * @param mixed $input Input data.

	 *

	 * @return mixed $input

	 */

	public function validate_settings( $input ) {

		// Do your settings validation here

		// Same as $sanitize_callback from http://codex.wordpress.org/Function_Reference/register_setting.

		return $input;

	}



	/**

	 * Load the required dependencies for this plugin.

	 *

	 * Include the following files that make up the plugin:

	 *

	 * - Appointy_Loader. Orchestrates the hooks of the plugin.

	 * - Appointy_i18n. Defines internationalization functionality.

	 * - Appointy_Admin. Defines all hooks for the admin area.

	 * - Appointy_Public. Defines all hooks for the public side of the site.

	 *

	 * Create an instance of the loader which will be used to register the hooks

	 * with WordPress.

	 *

	 * @since    1.0.0

	 * @access   private

	 */

	private function load_dependencies() {



		/**

		 * The class responsible for orchestrating the actions and filters of the

		 * core plugin.

		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-appointy-loader.php';



		/**

		 * The class responsible for defining internationalization functionality

		 * of the plugin.

		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-appointy-i18n.php';



		/**

		 * The class responsible for defining all actions that occur in the admin area.

		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-appointy-admin.php';

		

		/**

         * Custom Post Types

         */

        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-appointy-post-types.php';

		

		/**

         * Admin ajax call

         */

        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-appointy-admin-ajax.php';



		/**

		 * The class responsible for defining all actions that occur in the public-facing

		 * side of the site.

		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-appointy-public.php';

		

		require plugin_dir_path( dirname( __FILE__ ) ) . 'includes/libraries/class-appointy-template-loader.php';

		

		if ( file_exists( plugin_dir_path( dirname( __FILE__ ) ) . 'library/CMB2/init.php' ) ) {

		require plugin_dir_path( dirname( __FILE__ ) ) . 'library/CMB2/init.php';

		}

		

		/**

		 * Helpers

		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/side-menu-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/manage-uploads.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/router-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/media-upload-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/image-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/service-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/service-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/room-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/location-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/misc-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/form-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/map-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/staff-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/customer-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/availability-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/coupon-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/taxes-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/pdf-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/giftcards-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/booking-form-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/payment-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/invoice-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/appointments-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/emails-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/notifications-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/send-email-nitification-helper.php';

		if (PHP_VERSION_ID >= 80100) {

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/google-calendar-helper.php';

		}

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/sms-helper.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/login-helper.php';

		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

		if( is_plugin_active( 'video-conferencing-with-zoom-api/video-conferencing-with-zoom-api.php' ) ) {

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/zoom-helper.php';

		}

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/helpers/permission-helper.php';

		

		$this->loader = new Appointy_Loader();



	}



	/**

	 * Define the locale for this plugin for internationalization.

	 *

	 * Uses the Appointy_i18n class in order to set the domain and to register the hook

	 * with WordPress.

	 *

	 * @since    1.0.0

	 * @access   private

	 */

	private function set_locale() {



		$plugin_i18n = new Appointy_i18n();



		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );



	}



	/**

	 * Register all of the hooks related to the admin area functionality

	 * of the plugin.

	 *

	 * @since    1.0.0

	 * @access   private

	 */

	private function define_admin_hooks() {



		$plugin_admin = new Appointy_Admin( $this->get_plugin_name(), $this->get_version() );



		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		$this->loader->add_action( 'admin_footer', $plugin_admin, 'alerts_html_to_footer', 999 );

		$this->loader->add_action( 'fetch_gc_events', $plugin_admin, 'process_fetch_gc_events', 999 );

		$this->loader->add_action( 'activate_repeat_service', $plugin_admin, 'process_activate_repeat_service', 999 );

		

		$this->loader->add_action( 'cmb2_admin_init', $plugin_admin, 'process_cmb2_metaboxes' );

		

		$appointy_post_types = new Appointy_Post_Types();

		

		$this->loader->add_action( 'init', $appointy_post_types, 'create_custom_post_type', 999 );

		

		$taxonomy_fields = Appointy_Misc_Helper::get_taxonomy_metafields();

		

		foreach( $taxonomy_fields as $taxonomy_field ){

			$this->loader->add_action( 'manage_edit-'.$taxonomy_field.'_columns', $appointy_post_types, 'tax_columns', 999 );

			$this->loader->add_action( 'manage_'.$taxonomy_field.'_custom_column', $appointy_post_types, 'tax_column', 10, 3 );

			$this->loader->add_action( $taxonomy_field.'_add_form_fields', $appointy_post_types, 'add_fields_form', 999 );

			$this->loader->add_action( $taxonomy_field.'_edit_form_fields', $appointy_post_types, 'edit_fields_form', 999 );

		}

		

		$this->loader->add_action( 'create_term', $appointy_post_types, 'field_save', 999 );

		$this->loader->add_action( 'edit_term', $appointy_post_types, 'field_save', 999 );

		

		

		$this->loader->add_action( 'admin_menu', $plugin_admin, 'create_menu', 0 );

		

		$this->loader->add_action( 'admin_body_class', $plugin_admin, 'admin_body_class', 40 );

		

		$appointy_admin_jax = new Appointy_Admin_Ajax();

		

	}

	

	/**

	 * Register all of the hooks related to the public-facing functionality

	 * of the plugin.

	 *

	 * @since    1.0.0

	 * @access   private

	 */

	private function define_public_hooks() {



		$plugin_public = new Appointy_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		$this->loader->add_action( 'wp_footer', $plugin_public, 'alerts_html_to_footer', 999 );

		

		/**

		 * Register shortcode via loader

		 *

		 * Use: [short-code-name args]

		 *

		 */

		$this->loader->add_shortcode( "appointy-upload", $plugin_public, "appointy_upload", $priority = 10, $accepted_args = 2 );

		$this->loader->add_shortcode( "appointy-booking-form", $plugin_public, "appointy_booking_form", $priority = 10, $accepted_args = 2 );

		$this->loader->add_shortcode( "appointy-hotel-booking-form", $plugin_public, "appointy_hotel_booking_form", $priority = 10, $accepted_args = 1 ); //Booking form shortcode for single hotel room
		
		$this->loader->add_shortcode( "appointy-hotel-check-availability-form", $plugin_public, "appointy_hotel_check_availability_form", $priority = 10, $accepted_args = 1 ); //Booking form shortcode for single hotel room

		$this->loader->add_shortcode( "appointy-giftcard-payment", $plugin_public, "appointy_giftcard_payment", $priority = 10, $accepted_args = 2 );

		$this->loader->add_shortcode( "appointy-invoice-pay", $plugin_public, "appointy_invoice_payment", $priority = 10, $accepted_args = 2 );

		$this->loader->add_shortcode( "appointy-thank-you", $plugin_public, "appointy_thank_you", $priority = 10, $accepted_args = 0 );

		$this->loader->add_shortcode( "appointy-login", $plugin_public, "appointy_login", $priority = 10, $accepted_args = 0 );

		$this->loader->add_shortcode( "appointy-staff-dashboard", $plugin_public, "appointy_staff_dashboard", $priority = 10, $accepted_args = 0 );

		$this->loader->add_shortcode( "appointy-customer-dashboard", $plugin_public, "appointy_customer_dashboard", $priority = 10, $accepted_args = 0 );

		$this->loader->add_shortcode( "appointy-repeat-service-payment", $plugin_public, "appointy_repeat_service_payment", $priority = 10, $accepted_args = 2 );



	}



	/**

	 * Run the loader to execute all of the hooks with WordPress.

	 *

	 * @since    1.0.0

	 */

	public function run() {

		$this->loader->run();

	}



	/**

	 * The name of the plugin used to uniquely identify it within the context of

	 * WordPress and to define internationalization functionality.

	 *

	 * @since     1.0.0

	 * @return    string    The name of the plugin.

	 */

	public function get_plugin_name() {

		return $this->plugin_name;

	}



	/**

	 * The reference to the class that orchestrates the hooks with the plugin.

	 *

	 * @since     1.0.0

	 * @return    Appointy_Loader    Orchestrates the hooks of the plugin.

	 */

	public function get_loader() {

		return $this->loader;

	}



	/**

	 * Retrieve the version number of the plugin.

	 *

	 * @since     1.0.0

	 * @return    string    The version number of the plugin.

	 */

	public function get_version() {

		return $this->version;

	}



}

