<?php 
class Appointy_Availability_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		
		add_action('wp_ajax_appointy_save_workperiod', array($this, 'save_workperiod'));
		add_action('wp_ajax_appointy_save_custom_schedule', array($this, 'save_custom_schedule'));
		add_action('wp_ajax_appointy_load_custom_schedule', array($this, 'load_custom_schedule'));
		add_action('wp_ajax_appointy_delete_custom_schedule', array($this, 'delete_custom_schedule'));
		add_action('wp_ajax_appointy_save_holidays', array($this, 'save_holidays'));
		add_action('wp_ajax_appointy_delete_holidays', array($this, 'delete_holidays'));
		add_action('wp_ajax_appointy_load_work_period_slots', array($this, 'load_work_period_slots'));
		add_action('wp_ajax_appointy_save_workperiod_timeslots', array($this, 'save_workperiod_timeslots'));
		
		
    }
	
	/**
	 * Save work period
	 *
	 * @return array
	 */
	public static function save_workperiod( ) {
		global $wpdb;
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) ) {
			wp_send_json_error();
			die();
		}
		
		$user_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'user_id' );
		$data['member_id'] = $user_id;
		
		$weekdays = Appointy_Service_Helper::get_weekdays();
		
		$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `member_id` = %d AND `custom_date` IS NULL',$user_id));
		
		$flag = 0;
		
		if( !empty($weekdays) ) {
			foreach( $weekdays as $key => $value ) {
				$start_time = ( isset( $_POST['start_time'] ) ) ? (array)$_POST['start_time'] : array();
				$end_time = ( isset( $_POST['end_time'] ) ) ? (array)$_POST['end_time'] : array();
				$interval = ( isset( $_POST['interval'] ) ) ? (array)$_POST['interval'] : array();
				
				$status[$key] = ( isset( $_POST['status'][$key] ) ) ? true : false;
				if( $status[$key] ) {
				unset($start_time[$key][0]);
				unset($end_time[$key][0]);
				unset($interval[$key][0]);
				$arraymap = array_map(null,$start_time[$key],$end_time[$key],$interval[$key]);
				if( !empty($arraymap) ) {
					foreach ($arraymap as $arrkey => $arrvalue) {
						$starttime = ( !empty( $arrvalue[0] ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $arrvalue[0] ) ) ) : '';
						$endtime = ( !empty( $arrvalue[1] ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $arrvalue[1] ) ) ) : '';
						$startnumber = $endnumber = 0;
						if( $starttime != '' ) {
							$starttempcode = explode( ':',$starttime );	
							$starthour = ( !empty( $starttempcode[0] ) ) ? intval($starttempcode[0]) * 60 : 0;
							$startmin = ( !empty( $starttempcode[1] ) ) ? intval($starttempcode[1]) : 0;	
							$startnumber = intval($starthour) + intval($startmin);	
						}
						
						if( $endtime != '' ) {
							$endtempcode = explode( ':',$endtime );	
							$endhour = ( !empty( $endtempcode[0] ) ) ? intval($endtempcode[0]) * 60 : 0;
							$endmin = ( !empty( $endtempcode[1] ) ) ? intval($endtempcode[1]) : 0;	
							$endnumber = intval($endhour) + intval($endmin);	
						}
					
						$data['weekday'] 	= $key;
						$data['start_time'] 	= ( !empty( $arrvalue[0] ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $arrvalue[0] ) ) ) : NULL;
						$data['end_time'] 	= ( !empty( $arrvalue[1] ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $arrvalue[1] ) ) ) : NULL;
						$data['start_time_number'] 	= $startnumber;
						$data['end_time_number'] 	= $endnumber;
						$data['interval'] 	= ( !empty($arrvalue[2]) ) ? sanitize_text_field($arrvalue[2]) : '';
						$data['custom_date'] 	= NULL;
						
						if( !empty($arrvalue[0]) && !empty($arrvalue[1]) && !empty($arrvalue[2]) ) {
							$result = $wpdb->insert( $wpdb->prefix.'appointy_work_periods',wp_unslash( $data ) );
							$flag = 1;
						}
					}
					
				}
				}
			}
		}
		
		if( $flag === 0 ) {
			$response = array('msg' => esc_html__('Please select timeslots for enabled weekdays.','appointy'));
			wp_send_json_error($response);
			exit;
		}
		
		if ( $result === false ){
			$response = array('msg' => $wpdb->print_error());
			wp_send_json_error($response);
	    } else {
			$response = array( 'msg' => esc_html__('Information saved.', 'appointy') );
			wp_send_json_success($response);
	    }
		
   		die();
	}
	
	/**
	 * Save custom schedule
	 *
	 * @return array
	 */
	public static function save_custom_schedule( ) {
		global $wpdb;
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) ) {
			wp_send_json_error();
			die();
		}
		
		$user_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'user_id' );
		$data['member_id'] = $user_id;
		
		$custom_date = Appointy_Router_Helper::get_sanitize_data( $_POST, 'custom_date' );
		$custom_date = ( !empty( $custom_date ) ) ? wp_date( 'Y-m-d',strtotime( sanitize_text_field( $custom_date ) ) ) : NULL;
		
		$start_time = (!empty($_POST['start_time'])) ? $_POST['start_time'] : array();
		$end_time = (!empty($_POST['end_time'])) ? $_POST['end_time'] : array();
		$interval = (!empty($_POST['interval'])) ? $_POST['interval'] : array();
		
		unset($start_time['custom'][0]);
		unset($end_time['custom'][0]);
		unset($interval['custom'][0]);
		$arraymap = array_map(null,$start_time['custom'],$end_time['custom'],$interval['custom']);

		$flag = 0;
				
		if( !empty($arraymap) ) {
			$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `member_id` = %d AND `custom_date` = %s',$user_id,$custom_date));
			foreach ($arraymap as $arrkey => $arrvalue) {
				$starttime = ( !empty( $arrvalue[0] ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $arrvalue[0] ) ) ) : '';
				$endtime = ( !empty( $arrvalue[1] ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $arrvalue[1] ) ) ) : '';
				$startnumber = $endnumber = 0;
				if( $starttime != '' ) {
					$starttempcode = explode( ':',$starttime );	
					$starthour = ( !empty( $starttempcode[0] ) ) ? intval($starttempcode[0]) * 60 : 0;
					$startmin = ( !empty( $starttempcode[1] ) ) ? intval($starttempcode[1]) : 0;	
					$startnumber = intval($starthour) + intval($startmin);	
				}
				
				if( $endtime != '' ) {
					$endtempcode = explode( ':',$endtime );	
					$endhour = ( !empty( $endtempcode[0] ) ) ? intval($endtempcode[0]) * 60 : 0;
					$endmin = ( !empty( $endtempcode[1] ) ) ? intval($endtempcode[1]) : 0;	
					$endnumber = intval($endhour) + intval($endmin);	
				}
			
				$data['custom_date'] 	= ( !empty( $custom_date ) ) ? wp_date( 'Y-m-d',strtotime( sanitize_text_field( $custom_date ) ) ) : NULL;
				$data['start_time'] 	= ( !empty( $arrvalue[0] ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $arrvalue[0] ) ) ) : NULL;
				$data['end_time'] 	= ( !empty( $arrvalue[1] ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $arrvalue[1] ) ) ) : NULL;
				$data['start_time_number'] 	= $startnumber;
				$data['end_time_number'] 	= $endnumber;
				$data['interval'] 	= ( !empty($arrvalue[2]) ) ? sanitize_text_field($arrvalue[2]) : '';
				
				if(!empty($arrvalue[0]) && !empty($arrvalue[1]) && !empty($arrvalue[2]) ) {
					$result = $wpdb->insert( $wpdb->prefix.'appointy_work_periods',wp_unslash( $data ) );
					$flag = 1;
				}
			}
		}
		
		if( $flag === 0 ) {
			$response = array('msg' => esc_html__('Please select timeslots for selected date.','appointy'));
			wp_send_json_error($response);
			exit;
		}
		
		if ( $result === false ){
			$response = array('msg' => $wpdb->print_error());
			wp_send_json_error($response);
	    } else {
			$response = array( 'msg' => esc_html__('Information saved.', 'appointy') );
			wp_send_json_success($response);
	    }
		
   		die();
	}
	
	/**
	 * Process load custom schedule
	 *
	 * @return array
	 */
	public static function load_custom_schedule() {
		global $wpdb;
		
		$editcustomdate = Appointy_Router_Helper::get_request_data( $_POST, 'editcustomdate' );
		$user_id = Appointy_Router_Helper::get_request_data( $_POST, 'user_id' );
		
		$results = $wpdb->get_results($wpdb->prepare('SELECT `start_time`,`end_time`,`interval` FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `member_id` = %d AND `custom_date` = %s',$user_id,$editcustomdate));
		
		ob_start();
		
		$html = '';
		
		if( !empty( $results ) ) {
			foreach( $results as $key => $row ) {
				if( $row->start_time != NULL && $row->end_time != NULL ) {
				?>
                <li id="remove-editcustom<?php echo esc_attr($key); ?>" class="row customfield-working-hours editcustomfield-custom">
                    <div class="col-md-4 availibility-start">
                        <div class="form-group">
                            <div class="availibility-edit2">
                                <div class="availibility-time-select date timepicker">
                                    <input class="form-control sf-form-control starttimeinput" readonly="readonly" name="start_time[custom][]" type="text" value="<?php echo Appointy_Misc_Helper::get_time_format( $row->start_time ); ?>">
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-4 availibility-end">
                        <div class="form-group">
                            <div class="availibility-edit2">
                                <div class="availibility-time-select date timepicker">
                                    <input class="form-control sf-form-control endtimeinput" readonly="readonly" name="end_time[custom][]" type="text" value="<?php echo Appointy_Misc_Helper::get_time_format( $row->end_time ); ?>">
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-4 col-sm-6 sf-daytime-has">
                        <input readonly="readonly" class="form-control sf-form-control" name="interval[custom][]" type="text" value="<?php echo esc_attr($row->interval); ?>"> <div class="appointy-interval-suffix"><?php echo esc_html__( 'Mins', 'appointy' ); ?></div>
                    </div>
                    <button type="button" data-removeid="remove-editcustom<?php echo esc_attr($key); ?>" class="btn-time-remove remove-me" ><i class="feather-x"></i></button>
                </li>
				<?php
				}
			}
		}
		
		$html = ob_get_clean();
		
		$custom_date = ( !empty($editcustomdate) )? wp_date( Appointy_Misc_Helper::datepicker_php_format(),strtotime( esc_html( $editcustomdate ) ) ) : '';
		
		$response = array( 
			'html' => $html,
			'custom_date' => $custom_date,
		);
		wp_send_json_success($response);
		
   		die();
	}
	
	/**
	 * Process delete custom schedule
	 *
	 * @return array
	 */
	public static function delete_custom_schedule( ) {
		global $wpdb;
		
		$removecustomdate = Appointy_Router_Helper::get_request_data( $_POST, 'removecustomdate' );
		$user_id = Appointy_Router_Helper::get_request_data( $_POST, 'user_id' );
		
		$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `member_id` = %d AND `custom_date` = %s',$user_id,$removecustomdate));
		
		$response = array( 'msg' => esc_html__('Custom schedule date has deleted.', 'appointy') );
		wp_send_json_success($response);
		
   		die();
	}
	
	/**
	 * Process save holidays
	 *
	 * @return array
	 */
	public static function save_holidays( ) {
		global $wpdb;
		
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) ) {
			wp_send_json_error();
			die();
		}
		
		$user_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'user_id' );
		$data['member_id'] = $user_id;
		
		$multidates = Appointy_Router_Helper::get_sanitize_data( $_POST, 'multidates' );
		
		$multidates = explode(',',$multidates);
		$flag = 0;
		if( !empty( $multidates ) ) {
			foreach( $multidates as $multidate ) {
				
				if( $multidate != '' ) {
					$data['date'] 	= ( !empty( $multidate ) ) ? wp_date( 'Y-m-d',strtotime( sanitize_text_field( $multidate ) ) ) : NULL;
					$data['dayoff_type'] 	= 'multidate';
					$data['type'] 	= 'dayoff';
					
					$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `member_id` = %d AND `type` = "dayoff" AND `dayoff_type` = "multidate" AND `date` = %s',$user_id, wp_date( 'Y-m-d',strtotime( sanitize_text_field( $multidate ) ) )));
					
					$result = $wpdb->insert( $wpdb->prefix.'appointy_blocked_schedule',wp_unslash( $data ) );		
					$flag = 1;
				}
			}
		}
		
		$start_range = (!empty($_POST['start_range'])) ? $_POST['start_range'] : array();
		$end_range = (!empty($_POST['end_range'])) ? $_POST['end_range'] : array();
		
		$date_range = array_map(null,$start_range,$end_range);
		
		if( !empty( $date_range ) ) {
			foreach( $date_range as $range  ) {
				if($range[0] != '' && $range[1] != '') {
					$data['start_date'] 	= ( !empty( $range[0] ) ) ? wp_date( 'Y-m-d',strtotime( sanitize_text_field( $range[0] ) ) ) : NULL;
					$data['end_date'] 	= ( !empty( $range[1] ) ) ? wp_date( 'Y-m-d',strtotime( sanitize_text_field( $range[1] ) ) ) : NULL;
					$data['dayoff_type'] 	= 'daterange';
					$data['type'] 	= 'dayoff';
					
					$result = $wpdb->insert( $wpdb->prefix.'appointy_blocked_schedule',wp_unslash( $data ) );
					$flag = 1;
				}
			}
		}
		
		if( $flag === 0 ) {
			$response = array('msg' => esc_html__('Please select date range.','appointy'));
			wp_send_json_error($response);
			exit;
		}
		
		if ( $result === false ){
			$response = array('msg' => $wpdb->print_error());
			wp_send_json_error($response);
	    } else {
			$response = array( 'msg' => esc_html__('Information saved.', 'appointy') );
			wp_send_json_success($response);
	    }
		
   		die();
	}
	
	/**
	 * Process load work period slots
	 *
	 * @return array
	 */
	public static function load_work_period_slots( ) {
		global $wpdb;
		
		$user_id = Appointy_Router_Helper::get_request_data( $_POST, 'user_id' );
		
		$workperiod = (!empty($_POST['options'])) ? $_POST['options'] : array();
		
		ob_start();
		if( $workperiod['start_time'] != NULL && $workperiod['end_time'] != NULL ) {
			?>
			<div class="edit-time-title"><?php echo Appointy_Misc_Helper::get_time_format( $workperiod['start_time'] ). '-' .Appointy_Misc_Helper::get_time_format( $workperiod['end_time'] ); ?></div>
			<?php
			echo '<ul class="edit-time-lists showhideslot">';
			$begin = new \DateTime( $workperiod['start_time'] );
			$end = new \DateTime( $workperiod['end_time'] );
			$intval = \DateInterval::createFromDateString( intval( $workperiod['interval'] ).' min' );
			$available_start_times = new \DatePeriod($begin, $intval ,$end);
			foreach($available_start_times as $date){
			
			$row = $wpdb->get_row($wpdb->prepare('SELECT `id` FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `member_id` = %d AND `dayoff_type` = "timeslot" AND `type` = "dayoff" AND `start_time` = %s AND `day` = %s',$user_id,$date->format("H:i:s"),$workperiod['weekday']));
			?>
			<li class="<?php echo ( !empty( $row ) ) ? 'edit-time-hide active' : ''; ?>" data-timeslot="<?php echo esc_attr( $date->format("H:i:s") ); ?>" data-interval="<?php echo esc_attr( $workperiod['interval'] ); ?>">
                <i class="<?php echo ( !empty( $row ) ) ? 'feather-eye' : 'feather-eye-off'; ?>"></i>
                <span><?php echo $date->format( Appointy_Misc_Helper::get_wp_time_format() ); ?></span>
            </li>
			<?php
			}
			echo '</ul>';
		}
        ?>
		<?php
		$html = ob_get_clean();
		
		$response = array( 'msg' => esc_html__('Slots loaded.', 'appointy'), 'html' => $html );
		wp_send_json_success($response);
		
   		die();
	}
	
	/**
	 * Process delete holidays
	 *
	 * @return array
	 */
	public static function delete_holidays( ) {
		global $wpdb;
		
		$removeholidayid = Appointy_Router_Helper::get_request_data( $_POST, 'removeholidayid' );
		
		$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `id` = %d',$removeholidayid));
		
		$response = array( 'msg' => esc_html__('Holidays has deleted.', 'appointy') );
		wp_send_json_success($response);
		
   		die();
	}
	
	/**
	 * Process save work period slots
	 *
	 * @return array
	 */
	public static function save_workperiod_timeslots( ) {
		global $wpdb;
		
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) ) {
			wp_send_json_error();
			die();
		}
		
		$user_id = Appointy_Router_Helper::get_request_data( $_POST, 'user_id' );
		$data['member_id'] = $user_id;
		
		$timeslots = (!empty($_POST['timeslots'])) ? $_POST['timeslots'] : array();
		$interval = Appointy_Router_Helper::get_sanitize_data( $_POST, 'interval' );
		$day = Appointy_Router_Helper::get_sanitize_data( $_POST, 'day' );
		
		if( !empty( $timeslots ) ) {
			$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `member_id` = %d AND `dayoff_type` = "timeslot" AND `type` = "dayoff" AND `day` = %s',$user_id,$day));
			foreach( $timeslots as $timeslot ) {
				$data['day'] 	= ( isset( $day ) ) ? sanitize_text_field( $day ) : '';
				$data['start_time'] 	= ( !empty( $timeslot ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $timeslot ) ) ) : NULL;
				$end_time = date('H:i:s', strtotime($timeslot." +".$interval." minutes"));
				$data['end_time'] 	= ( !empty( $timeslot ) ) ? $end_time : NULL;
				$data['dayoff_type'] 	= 'timeslot';
				$data['type'] 	= 'dayoff';
				
				$result = $wpdb->insert( $wpdb->prefix.'appointy_blocked_schedule',wp_unslash( $data ) );
			}
		}
		
		if ( $result === false ){
			$response = array('msg' => $wpdb->print_error());
			wp_send_json_error($response);
	    } else {
			$response = array( 'msg' => esc_html__('Information saved.', 'appointy') );
			wp_send_json_success($response);
	    }
		
   		die();
	}
	
	/**
	 * Get Intervals
	 *
	 * @return array
	 */
	public static function get_intervals() {
		$period = Appointy_Misc_Helper::get_settings( 'general_settings', 'avl_interval_period',15 );
		$start = Appointy_Misc_Helper::get_settings( 'general_settings', 'avl_interval_start_time',15 );
		$end = Appointy_Misc_Helper::get_settings( 'general_settings', 'avl_interval_end_time',240 );
		
		$intervals = array();
		for($i = $start;$i <= $end;$i = $i + $period){
			$intervals[$i] = self::convert_hours_mins_format($i, '%02dH:%02dM');
		}
		
		return $intervals;
	}
	
	/**
	 * Get convert hours/min format
	 *
	 * @return array
	 */
	public static function convert_hours_mins_format($time, $format = '%02d:%02d')	{
		if ($time < 1) {
			return;
		}
		$hours = floor($time / 60);
		$minutes = ($time % 60);
		return sprintf($format, $hours, $minutes);
	}
	
	/**
	 * Get custom schedule
	 *
	 * @return array
	 */
	public static function get_custom_schedule( $user_id = 0, $year = '' ) {
		global $wpdb;
		
		if( $year != '' ) {
			$results = $wpdb->get_results( $wpdb->prepare( 'SELECT `id`,`member_id`,`start_time`,`end_time`,`start_time_number`,`end_time_number`,`weekday`,`weekday_number`,`interval`,`custom_date` FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `member_id` = %d AND year(custom_date) = %d AND `custom_date` IS NOT NULL group by `custom_date`',$user_id, $year ) );	
		} else {
			$results = $wpdb->get_results( $wpdb->prepare( 'SELECT `id`,`member_id`,`start_time`,`end_time`,`start_time_number`,`end_time_number`,`weekday`,`weekday_number`,`interval`,`custom_date` FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `member_id` = %d AND `custom_date` IS NOT NULL group by `custom_date`',$user_id ) );
		}
		
		
		return $results;
	}
	
	/**
	 * Get custom schedule slots
	 *
	 * @return array
	 */
	public static function get_custom_schedule_slots( $user_id = 0, $date = '' ) {
		global $wpdb;
		
		$results = $wpdb->get_results( $wpdb->prepare( 'SELECT `id`,`member_id`,`start_time`,`end_time`,`start_time_number`,`end_time_number`,`weekday`,`weekday_number`,`interval`,`custom_date` FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `member_id` = %d AND `custom_date` = %s',$user_id, $date ) );
		
		return $results;
	}
	
	/**
	 * Get holidays
	 *
	 * @return array
	 */
	public static function get_holidays( $user_id = 0, $year = '' ) {
		global $wpdb;
		
		$results = $wpdb->get_results( $wpdb->prepare( 'SELECT `id`,`member_id`,`branch_id`,`appointment_id`,`dayoff_type`,`date`,`day`,`start_date`,`end_date`,`start_time`,`end_time`,`start_time_number`,`end_time_number`,`type` FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `member_id` = %d AND (`dayoff_type` = "daterange" OR `dayoff_type` = "multidate") AND (year(date) = %d OR year(start_date) = %d OR year(end_date) = %d) order by `start_date` ASC, `date` ASC',$user_id, $year, $year, $year ) );
		
		return $results;
	}
	
	/**
	 * Get work periods
	 *
	 * @return array
	 */
	public static function get_work_periods( $user_id = 0,$weekday = '' ) {
		global $wpdb;
		
		$results = $wpdb->get_results( $wpdb->prepare( 'SELECT `id`,`member_id`,`start_time`,`end_time`,`start_time_number`,`end_time_number`,`weekday`,`weekday_number`,`interval`,`custom_date` FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `member_id` = %d AND `weekday` = %s AND `custom_date` IS NULL',$user_id, $weekday ) );
		
		return $results;
	}
}
new Appointy_Availability_Helper();
