<?php 
class Appointy_Google_Calendar_Helper {

	 /** @var string */
    protected $timezone;

	public function __construct() {
		
		/**
		 * Ajax hook
		 */
		add_action( 'init', [ $this, 'google_calendar_auth' ] );
		
		add_action('wp_ajax_update_google_calendar_id', array($this, 'update_google_calendar_id'));
		add_action('wp_ajax_disconnect_google_calendar', array($this, 'disconnect_google_calendar'));
		add_action('wp_ajax_sync_with_google_calendar_events', array($this, 'sync_with_google_calendar_events'));
	}
	
	/**
	 * Update google calendar id
	 *
	 * @return array
	 */
	public static function update_google_calendar_id() {
		global $wpdb, $current_user;
		
		$user_id = $current_user->ID;
		
		$google_calendar_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'google_calendar_id' );
		
		update_user_meta($user_id,'google_calendar_id',$google_calendar_id);
		
		$response = array(
						'message'   => esc_html__('Google calendar id updated successfully.','appointy')
					);
		wp_send_json_success($response);
		exit;
	}
	
	/**
	 * Disconnect google calendar
	 *
	 * @return array
	 */
	public static function disconnect_google_calendar() {
		global $wpdb, $current_user;
		
		require_once KARIB_PLUGIN_DIR . '/library/google/vendor/autoload.php';



		$clientID = Karib_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_id' );
		
		$clientSecret = Karib_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_secret' );
		
		$redirectUri = KARIB_GCAL_REDIRECT_URI;
		
		
		
		// Create Google Client
		
		$client = new Google_Client();
		
		$client->setClientId($clientID);
		
		$client->setClientSecret($clientSecret);
		
		$client->setRedirectUri($redirectUri);
		
		$client->setAccessType("offline");
		
		$client->setApprovalPrompt('force');
		
		$client->addScope(Google_Service_Calendar::CALENDAR);

		$user_id = $current_user->ID;

		

		$accessToken = get_user_meta($user_id,'gcal_access_token',true);
		
		if($accessToken != '') {

			if(Karib_Router_Helper::get_sanitize_data( $accessToken, 'refresh_token' ) != '') {
	
				$client->setAccessToken($accessToken);
	
				
	
				if($client->isAccessTokenExpired()) {
	
				 $client->fetchAccessTokenWithRefreshToken($client->getRefreshToken());
	
				 $newAccessToken = $client->getAccessToken();
	
				 $client->setAccessToken($newAccessToken); 
				
					$accessToken = $newAccessToken['access_token'];
				}else{
					$accessToken = $accessToken['access_token'];		
				}
	
			}
	
		}
		
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, 'https://accounts.google.com/o/oauth2/revoke?token=' . $accessToken);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		
		$response = curl_exec($ch);
		$status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		
		curl_close($ch);
		
		if ($status == 200) {
			delete_user_meta($user_id,'google_calendar_id');
			delete_user_meta($user_id,'gcal_access_token');
			
			$response = array(
							'message'   => esc_html__('Google calendar disconnected successfully.','appointy')
						);
			wp_send_json_success($response);
			exit;
		} else {
			$response = array(
							'message'   => esc_html__('Error revoking access token: ','appointy') . $response
						);
			wp_send_json_error($response);
			exit;
		}
	}
	
	/**
	 * Sync with google calendar events
	 *
	 * @return array
	 */
	public static function sync_with_google_calendar_events() {
		global $wpdb, $current_user;
		
		$user_id = $current_user->ID;
		
		self::fetchGoogleCalendarAppointments($user_id);
		
		$response = array(
						'message'   => esc_html__('Google calendar events fetched successfully.','appointy')
					);
		wp_send_json_success($response);
		exit;
	}
	
	/**
	 * Connnect to google calendar
	 *
	 * @return void
	 */
	public static function google_calendar_auth() {
		$current_user = wp_get_current_user();
		$user_roles = $current_user->roles;
		
		$user_id = $current_user->ID;
		
		if( Appointy_Router_Helper::get_sanitize_data( $_GET, 'action' ) === 'googleoauth-callback' && isset( $_GET['code'] ) ) {
			require_once APPOINTY_PLUGIN_DIR . '/library/google/vendor/autoload.php';
			$clientID = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_id' );
			$clientSecret = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_secret' );
			$redirectUri = APPOINTY_GCAL_REDIRECT_URI;
			
			$authcode = Appointy_Router_Helper::get_sanitize_data( $_GET, 'code' );
			
			// Create Google Client
			$client = new Google_Client();
			$client->setClientId($clientID);
			$client->setClientSecret($clientSecret);
			$client->setRedirectUri($redirectUri);
			$client->setAccessType("offline");
			$client->setApprovalPrompt('force');
			$client->setScopes(Google_Service_Calendar::CALENDAR);	
			
			$client->authenticate($_GET['code']);
		    $accessToken = $client->getAccessToken();
			
			//echo '<pre>';print_r($client);echo '</pre>';
			
			update_user_meta($user_id,'gcal_access_token',$accessToken);
			
			if(in_array('appointy_staff',$user_roles)) {
				$staff_dashboard_url = Appointy_Misc_Helper::get_url_by_shortcode( '[appointy-staff-dashboard' );
				$google_calendar_url = add_query_arg( array( 'navitem' => 'google-calendar', 'gcal' => 'connected' ), $staff_dashboard_url );
			}elseif(in_array('appointy_customer',$user_roles)) {
				$customer_dashboard_url = Appointy_Misc_Helper::get_url_by_shortcode( '[appointy-customer-dashboard' );
				$google_calendar_url = add_query_arg( array( 'navitem' => 'google-calendar', 'gcal' => 'connected' ), $customer_dashboard_url );
			}elseif(in_array('administrator',$user_roles)) {
				$google_calendar_url = add_query_arg( array( 'page' => 'appointment', 'menu_item' => 'google-calendar__index', 'gcal' => 'connected' ), admin_url('admin.php') );
			}
			
			header('Location: ' . filter_var($google_calendar_url, FILTER_SANITIZE_URL));
			exit;
		}
	}
	
	public static function date_format_RFC3339($timestamp = 0, $offset = 0) {
			$timezone = get_option('timezone_string');
			
			$date = new DateTime(date('Y-m-d H:i:s', $timestamp), new DateTimeZone($timezone));
			return $date->format(DateTime::RFC3339);
	}
	
	/**
	 * Fetch google calendar appointments
	 *
	 * @return void
	 */
	public static function fetchGoogleCalendarAppointments($member_id = 0) {
		global $wpdb;
		
		require_once APPOINTY_PLUGIN_DIR . '/library/google/vendor/autoload.php';
	
		$clientID = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_id' );
		$clientSecret = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_secret' );
		$redirectUri = APPOINTY_GCAL_REDIRECT_URI;
		
		// Create Google Client
		$client = new Google_Client();
		$client->setClientId($clientID);
		$client->setClientSecret($clientSecret);
		$client->setRedirectUri($redirectUri);
		$client->addScope(Google_Service_Calendar::CALENDAR);
		
		$accessToken = get_user_meta($member_id,'gcal_access_token',true);
		$calendarId = get_user_meta($member_id,'google_calendar_id',true);
		
		if($accessToken != '' && $calendarId != '') {
		$client->setAccessToken($accessToken);
		
		$service  = new Google_Service_Calendar($client);
		
		try {
            $result       = array();
            $limit_events = 50;
            $time_min     = date('c');

            $params = array(
                'singleEvents' => true,
                'orderBy'      => 'startTime',
                'timeMin'      => $time_min,
                'maxResults'   => $limit_events
            );

            do {
                // Fetch events.
				$events = $service->events->listEvents($calendarId, $params);

                foreach ( $events->getItems() as $key => $event ) {
                    if ( $event->getTransparency() != 'transparent' ) {
                        $ext_properties = $event->getExtendedProperties();
                        if ( $ext_properties !== null ) {
                            $private = $ext_properties['private'];
                            if (
                                is_array( $private ) && (
                                    array_key_exists( 'appointy', $private ) ||
                                    array_key_exists( 'appointment_id', $private )  // Backward compatibility
                                )
                            ) {
                                // Skip events created by Bookly.
                                continue;
                            }
                        }

                        // Get start/end dates of event and transform them into WP timezone (Google doesn't transform whole day events into our timezone).
                        $event_start = $event->getStart();
                        $event_end   = $event->getEnd();

                        if ( $event_start['dateTime'] == null ) {
							 $this->timezone = $client->service()->calendarList->get( $calendarId )->getTimeZone();
						
                            // All day event.
                            $event_start_date = new \DateTime( $event_start['date'], new \DateTimeZone( $this->timezone ) );
                            $event_end_date = new \DateTime( $event_end['date'], new \DateTimeZone( $this->timezone ) );
                        } else {
                            // Regular event.
                            $event_start_date = new \DateTime( $event_start['dateTime'] );
                            $event_end_date = new \DateTime( $event_end['dateTime'] );
                        }

                        // Convert to WP time zone.
                        $event_start_date = date_timestamp_set( date_create( get_option('timezone_string') ), $event_start_date->getTimestamp() );
                        $event_end_date   = date_timestamp_set( date_create( get_option('timezone_string') ), $event_end_date->getTimestamp() );

                        // Populate result.
                        $result[$key]['event_start_date'] = $event_start_date->format( 'Y-m-d' );
						$result[$key]['event_end_date'] = $event_end_date->format( 'Y-m-d' );
						
						$result[$key]['event_start_time'] = $event_start_date->format( 'H:i:s' );
						$result[$key]['event_end_time'] = $event_end_date->format( 'H:i:s' );
                    }
                }

                $params['pageToken'] = $events->getNextPageToken();

            } while ( ! $limit_events && $params['pageToken'] !== null );
			
			$user_roles = Appointy_Misc_Helper::get_user_roles($member_id);
			
			if(!empty($result)) {
				foreach($result as $row){
					$event_start_date = Appointy_Router_Helper::get_sanitize_data( $row, 'event_start_date' );
					$event_end_date = Appointy_Router_Helper::get_sanitize_data( $row, 'event_end_date' );
					$event_start_time = Appointy_Router_Helper::get_sanitize_data( $row, 'event_start_time' );
					$event_end_time = Appointy_Router_Helper::get_sanitize_data( $row, 'event_end_time' );
					
					if(in_array('appointy_staff',$user_roles)) {
					$blockedrow = $wpdb->get_row($wpdb->prepare('SELECT `id` FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `member_id` = %d AND `dayoff_type` = "timeslot" AND `type` = "booking" AND `start_time` = %s AND `end_time` = %s AND `date` = %s',$member_id,$event_start_time,$event_end_time,$event_start_date));
					}else{
					$blockedrow = $wpdb->get_row($wpdb->prepare('SELECT `id` FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `dayoff_type` = "timeslot" AND `type` = "booking" AND `start_time` = %s AND `end_time` = %s AND `date` = %s',$event_start_time,$event_end_time,$event_start_date));
					}
					
					
					if(empty($blockedrow)) {
						$bookingdata['dayoff_type'] 	= 'timeslot';
						$bookingdata['type'] 			= 'booking';
						$bookingdata['date'] 			= $event_start_date;
						$bookingdata['start_time'] 		= $event_start_time;
						$bookingdata['end_time'] 		= $event_end_time;
						if(in_array('appointy_staff',$user_roles)) {
							$bookingdata['member_id'] 		= $member_id;
						}
						
						$wpdb->insert($wpdb->prefix.'appointy_blocked_schedule',wp_unslash($bookingdata));
					}
				}
			}

            //echo '<pre>';print_r($result);echo '</pre>';

        } catch ( \Exception $e ) {
            echo $e->getMessage();
        }
		}
	}	
	
	/**
	 * add to google calendar appointment
	 *
	 * @return void
	 */
	public static function addToGoogleCalendarAppointment( $appointment_id = 0,$service_id = 0,$member_id = 0, $booked_service = array() ) {
		global $wpdb;
		
		$accessToken = get_user_meta($member_id,'gcal_access_token',true);
		
		if($accessToken == '') {
			return;
		}
	
		require_once APPOINTY_PLUGIN_DIR . '/library/google/vendor/autoload.php';
	
		$clientID = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_id' );
		$clientSecret = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_secret' );
		$redirectUri = APPOINTY_GCAL_REDIRECT_URI;
		
		// Create Google Client
		$client = new Google_Client();
		$client->setClientId($clientID);
		$client->setClientSecret($clientSecret);
		$client->setRedirectUri($redirectUri);
		$client->addScope(Google_Service_Calendar::CALENDAR);
		
		$accessToken = get_user_meta($member_id,'gcal_access_token',true);
		try {
		if($accessToken != '') {
		$client->setAccessToken($accessToken);
		if($client->isAccessTokenExpired()) {
		 $client->fetchAccessTokenWithRefreshToken($client->getRefreshToken());
		 $newAccessToken = $client->getAccessToken();
		 $client->setAccessToken($newAccessToken); 
		 $client->setScopes($newAccessToken['scope']);
		}
		$service = new Google_Service_Calendar($client);
		
		$booking_date = Appointy_Router_Helper::get_sanitize_data($booked_service,'booking_date');
		$booking_start_time = Appointy_Router_Helper::get_sanitize_data($booked_service,'booking_start_time');
		
		$hours = Appointy_Router_Helper::get_sanitize_data($booked_service,'hours');
		$minutes = Appointy_Router_Helper::get_sanitize_data($booked_service,'minutes');
		
		$duration = Appointy_Booking_Form_Helper::get_duration($hours,$minutes);
		
		$booking_end_time = date(Appointy_Misc_Helper::get_wp_time_format(), strtotime($booking_date.' '.$booking_start_time." +".sanitize_text_field($duration)." minutes"));
		
		$offset = 0;
		$startdatetime = strtotime($booking_date.' '.$booking_start_time);
		$startdatetime = self::date_format_RFC3339($startdatetime, $offset);
		
		$enddatetime = strtotime($booking_date.' '.$booking_end_time);
		$enddatetime = self::date_format_RFC3339($enddatetime, $offset);
		
		$customer_email = get_post_meta( $appointment_id, 'email', true );
		$serviceperformat = get_post_meta( $appointment_id, 'serviceperformat', true );
		$description = get_post_meta( $appointment_id, 'description', true );
		
		$service_name = Appointy_Router_Helper::get_sanitize_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_sanitize_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_sanitize_data($booked_service,'variation_name');

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;
		
		$user_roles = Appointy_Misc_Helper::get_user_roles($member_id);
		
		$attendees_email = '';
		if(in_array('appointy_customer',$user_roles)) {
			$staff_member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');
			if($staff_member_id > 0) {
			$staff_member_email = Appointy_Misc_Helper::get_email_by_user_id($staff_member_id);
			$attendees_email = $staff_member_email;
			}
		}else{
			$attendees_email = $customer_email;
		}
		
		if($attendees_email != '') {
			$event = new Google_Service_Calendar_Event(array(
				'summary' => $service_name,
				'location' => $serviceperformat,
				'description' => $description,
				'start' => array(
					 'dateTime' => $startdatetime,
					'timeZone' => get_option('timezone_string'),
				),
				'end' => array(
					 'dateTime' => $enddatetime,
					'timeZone' => get_option('timezone_string'),
				),
				'attendees' => array(
					array( 'email' => $attendees_email )
				),
			));
		}else{
			$event = new Google_Service_Calendar_Event(array(
				'summary' => $service_name,
				'location' => $serviceperformat,
				'description' => $description,
				'start' => array(
					 'dateTime' => $startdatetime,
					'timeZone' => get_option('timezone_string'),
				),
				'end' => array(
					 'dateTime' => $enddatetime,
					'timeZone' => get_option('timezone_string'),
				)
			));
		}
	
		$google_calendar_id = get_user_meta($member_id,'google_calendar_id',true);
		//echo '<pre>';print_r($event);echo '</pre>';
		$event = $service->events->insert($google_calendar_id, $event);
		
		if(in_array('appointy_customer',$user_roles)) {
			$eventdate['customer_google_calendar_url']	= $event->htmlLink;
			$eventdate['customer_google_calendar_event_id']	= $event->id;
		}elseif(in_array('appointy_staff',$user_roles)) {
			$eventdate['google_calendar_url']	= $event->htmlLink;
			$eventdate['google_calendar_event_id']	= $event->id;
		}elseif(in_array('administrator',$user_roles)) {
			$eventdate['admin_google_calendar_url']	= $event->htmlLink;
			$eventdate['admin_google_calendar_event_id']	= $event->id;
		}
					
		$where = array(
			'id' => $service_id
		);
		$wpdb->update($wpdb->prefix.'appointy_booked_services',wp_unslash($eventdate),$where);
		}
		
		}catch(Exception $e){
			return $e->getMessage();
		}
		//echo '<pre>';print_r($event);echo '</pre>';
		
		//echo 'Event created: ' . $event->htmlLink;
	}	
	
	/**
	 * update to google calendar appointment
	 *
	 * @return void
	 */
	public static function updateToGoogleCalendarAppointment( $appointment_id = 0,$service_id = 0,$member_id = 0, $booked_service = array() ) {
		global $wpdb;
		
		$accessToken = get_user_meta($member_id,'gcal_access_token',true);
		
		if($accessToken == '') {
			return;
		}
	
		require_once APPOINTY_PLUGIN_DIR . '/library/google/vendor/autoload.php';
	
		$clientID = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_id' );
		$clientSecret = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_secret' );
		$redirectUri = APPOINTY_GCAL_REDIRECT_URI;
		
		// Create Google Client
		$client = new Google_Client();
		$client->setClientId($clientID);
		$client->setClientSecret($clientSecret);
		$client->setRedirectUri($redirectUri);
		$client->addScope(Google_Service_Calendar::CALENDAR);
		
		$accessToken = get_user_meta($member_id,'gcal_access_token',true);
		
		try {
		if($accessToken != '') {
		$client->setAccessToken($accessToken);
		
		if($client->isAccessTokenExpired()) {
		 $client->fetchAccessTokenWithRefreshToken($client->getRefreshToken());
		 $newAccessToken = $client->getAccessToken();
		 $client->setAccessToken($newAccessToken); 
		}
		
		$service = new Google_Service_Calendar($client);
		
		$booking_date = Appointy_Router_Helper::get_sanitize_data($booked_service,'booking_date');
		$booking_start_time = Appointy_Router_Helper::get_sanitize_data($booked_service,'booking_start_time');
		
		
		$hours = Appointy_Router_Helper::get_sanitize_data($booked_service,'hours');
		$minutes = Appointy_Router_Helper::get_sanitize_data($booked_service,'minutes');
		
		$duration = Appointy_Booking_Form_Helper::get_duration($hours,$minutes);
		
		$booking_end_time = date(Appointy_Misc_Helper::get_wp_time_format(), strtotime($booking_date.' '.$booking_start_time." +".sanitize_text_field($duration)." minutes"));
		
		$offset = 0;
		$startdatetime = strtotime($booking_date.' '.$booking_start_time);
		$startdatetime = self::date_format_RFC3339($startdatetime, $offset);
		
		$enddatetime = strtotime($booking_date.' '.$booking_end_time);
		$enddatetime = self::date_format_RFC3339($enddatetime, $offset);
		
		$customer_email = get_post_meta( $appointment_id, 'email', true );
		$serviceperformat = get_post_meta( $appointment_id, 'serviceperformat', true );
		$description = get_post_meta( $appointment_id, 'description', true );
		
		$service_name = Appointy_Router_Helper::get_sanitize_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_sanitize_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_sanitize_data($booked_service,'variation_name');
		
		$user_roles = Appointy_Misc_Helper::get_user_roles($member_id);
		
		if(in_array('appointy_customer',$user_roles)) {
			$google_calendar_event_id = Appointy_Router_Helper::get_sanitize_data($booked_service,'customer_google_calendar_event_id');
		}elseif(in_array('appointy_staff',$user_roles)) {
			$google_calendar_event_id = Appointy_Router_Helper::get_sanitize_data($booked_service,'google_calendar_event_id');
		}elseif(in_array('administrator',$user_roles)) {
			$google_calendar_event_id = Appointy_Router_Helper::get_sanitize_data($booked_service,'admin_google_calendar_event_id');
		}
		
		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;
		
		$google_calendar_id = get_user_meta($member_id,'google_calendar_id',true);
		$cal = new Google_Service_Calendar($client);
		$event = $cal->events->get($google_calendar_id,$google_calendar_event_id);
		
		$start = new Google_Service_Calendar_EventDateTime();
		$start->setDateTime($startdatetime);
		$event->setStart($start);
		
		$end = new Google_Service_Calendar_EventDateTime();
		$end->setDateTime($enddatetime);
		$event->setEnd($end);
		
		$updatedEvent = $cal->events->update($google_calendar_id, $event->getId(), $event);

		$updatedEvent->getUpdated();
		
		}
		}catch(Exception $e){
			return $e->getMessage();
		}
	}
	
	/**
	 * cancel to google calendar appointment
	 *
	 * @return void
	 */
	public static function cancelToGoogleCalendarAppointment( $appointment_id = 0,$service_id = 0,$member_id = 0, $booked_service = array() ) {
		global $wpdb;
		
		$accessToken = get_user_meta($member_id,'gcal_access_token',true);
		
		if($accessToken == '') {
			return;
		}
	
		require_once APPOINTY_PLUGIN_DIR . '/library/google/vendor/autoload.php';
	
		$clientID = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_id' );
		$clientSecret = Appointy_Misc_Helper::get_settings( 'google_calendar_settings', 'google_calendar_client_secret' );
		$redirectUri = APPOINTY_GCAL_REDIRECT_URI;
		
		// Create Google Client
		$client = new Google_Client();
		$client->setClientId($clientID);
		$client->setClientSecret($clientSecret);
		$client->setRedirectUri($redirectUri);
		$client->addScope(Google_Service_Calendar::CALENDAR);
		
		$accessToken = get_user_meta($member_id,'gcal_access_token',true);
		try {
		if($accessToken != '') {
		$client->setAccessToken($accessToken);
		
		if($client->isAccessTokenExpired()) {
		 $client->fetchAccessTokenWithRefreshToken($client->getRefreshToken());
		 $newAccessToken = $client->getAccessToken();
		 $client->setAccessToken($newAccessToken); 
		}
		
		$google_calendar_id = get_user_meta($member_id,'google_calendar_id',true);
		
		$user_roles = Appointy_Misc_Helper::get_user_roles($member_id);
		
		if(in_array('appointy_customer',$user_roles)) {
			$google_calendar_event_id = Appointy_Router_Helper::get_sanitize_data($booked_service,'customer_google_calendar_event_id');
		}elseif(in_array('appointy_staff',$user_roles)) {
			$google_calendar_event_id = Appointy_Router_Helper::get_sanitize_data($booked_service,'google_calendar_event_id');
		}elseif(in_array('administrator',$user_roles)) {
			$google_calendar_event_id = Appointy_Router_Helper::get_sanitize_data($booked_service,'admin_google_calendar_event_id');
		}
		
		$cal = new Google_Service_Calendar($client);
		$cal->events->delete($google_calendar_id, $google_calendar_event_id);
		
		if(in_array('appointy_customer',$user_roles)) {
			$eventdate['customer_google_calendar_url']	= '';
			$eventdate['customer_google_calendar_event_id']	= '';
		}elseif(in_array('appointy_staff',$user_roles)) {
			$eventdate['google_calendar_url']	= '';
			$eventdate['google_calendar_event_id']	= '';
		}elseif(in_array('administrator',$user_roles)) {
			$eventdate['admin_google_calendar_url']	= '';
			$eventdate['admin_google_calendar_event_id']	= '';
		}
					
		$where = array(
			'id' => $service_id
		);
		$wpdb->update($wpdb->prefix.'appointy_booked_services',wp_unslash($eventdate),$where);
		
		}
		}catch(Exception $e){
			return $e->getMessage();
		}
	}	
}
new Appointy_Google_Calendar_Helper();