<?php
class Appointy_Manage_Uploads {

	public function __construct() {

		/**
		 * Ajax hook
		 */
		add_action( 'init', [ $this, 'download_file' ] );
		add_action( 'wp_ajax_image_upload', [ $this, 'image_upload_handler' ] );
		add_action( 'wp_ajax_nopriv_image_upload', [ $this, 'image_upload_handler' ] );
		
		add_action( 'wp_ajax_senddeleterequest', [ $this, 'delete_requested_file' ] );
		add_action( 'wp_ajax_nopriv_senddeleterequest', [ $this, 'delete_requested_file' ] );
	}

	/**
	 * Download file
	 *
	 * @return void
	 */
	public static function download_file() {
		global $wp_filesystem;
		
		if( isset( $_GET["attachment_id"] ) && isset( $_GET['download_file'] ) ) {
			if ( empty( $wp_filesystem ) ) {
				  require_once ABSPATH . '/wp-admin/includes/file.php';
				  WP_Filesystem();
			}
			//get filedata
			$attID = Appointy_Router_Helper::get_sanitize_data( $_GET, 'attachment_id' );
			$theFile = wp_get_attachment_url( $attID );
			
			if( ! $theFile ) {
				return;
			}
			//clean the fileurl
			$file_url  = stripslashes( trim( $theFile ) );
			//get filename
			$file_name = basename( $theFile );
			//get fileextension
			
			$file_extension = pathinfo($file_name);
			//security check
			$fileName = strtolower($file_url);
			
			$whitelist = apply_filters( "appointy_file_types", array("doc","docx","pdf","xls","xlsx","rtf","txt","ppt","pptx","jpg","jpeg","png","csv","gif") );
			
			if(!in_array($file_extension['extension'],$whitelist) ) {
				exit('Invalid file!');
			}

			if(strpos( $file_url , '.php' ) == true) {
				die("Invalid file!");
			}
			
			$file_new_name = $file_name;
			$content_type = "";
			//check filetype
			switch( $file_extension['extension'] ) {
				case "png": 
				  $content_type="image/png"; 
				  break;
				case "gif": 
				  $content_type="image/gif"; 
				  break;
				case "tiff": 
				  $content_type="image/tiff"; 
				  break;
				case "jpeg":
				case "jpg": 
				  $content_type="image/jpg"; 
				  break;
				default: 
				  $content_type="application/force-download";
			}
			
			$content_type = apply_filters( "ibenic_content_type", $content_type, $file_extension['extension'] );
			
			header("Expires: 0");
			header("Cache-Control: no-cache, no-store, must-revalidate"); 
			header('Cache-Control: pre-check=0, post-check=0, max-age=0', false); 
			header("Pragma: no-cache");	
			header("Content-type: {$content_type}");
			header("Content-Disposition:attachment; filename={$file_new_name}");
			header("Content-Type: application/force-download");
			
			print_r($wp_filesystem->get_contents($file_url));
			exit();
		}
	}
	
	/**
	 * Manage image upload
	 *
	 * @return void
	 */
	public static function image_upload_handler() {
	    global $wpdb;

		$field_id = isset( $_REQUEST['field_id'] ) ? $_REQUEST['field_id'] : '';
		$file = isset( $_FILES['async-upload'] ) ? $_FILES['async-upload'] : '';
		
		$file_attr = wp_handle_upload( $file, array( 'test_form' => false ) );
		
		$attachment = array(
			'guid'           => $file_attr['url'],
			'post_mime_type' => $file_attr['type'],
			'post_title'     => '',//preg_replace( '/\.[^.]+$/', '', basename( $file['name'] ) ),
			'post_content'   => '',
			'post_status'    => 'inherit',
		);
		
		$post_id = 0;
		$id = wp_insert_attachment( $attachment, $file_attr['file'], $post_id );
		
		if ( ! is_wp_error( $id ) )
		{
			wp_update_attachment_metadata( $id, wp_generate_attachment_metadata( $id, $file_attr['file'] ) );
			
			switch( $field_id ){
				case 'useravatar':
					wp_send_json_success( self::save_avatar_upload( $id, $file_attr ) );
					break;
				default:
					wp_send_json_success( self::save_default_upload( $id, $field_id ) );
					break;	
			}
		}	
		exit;
	}

	/* Avatar Upload */
	public static function save_avatar_upload( $id = 0, $attr = array() )
	{
		global $wpdb;	
		
		$user_id  = isset( $_REQUEST['user_id'] ) ? intval( $_REQUEST['user_id'] ) : 0;
		
		update_post_meta($id, '_wp_attachment_wp_user_avatar', $user_id);
		update_user_meta($user_id, $wpdb->get_blog_prefix().'user_avatar', $id);
		
		$title_delete = apply_filters( 'rwmb_image_delete_string', _x( 'Delete', 'image upload', 'appointy' ) );
		
		$li = '<li id="item_%s">
						<div class="aon-proAvtar-media">
							<img src="%s" alt="">
						</div>
						<div class="rwmb-image-bar">
							<a title="%s" class="sk-delete-file sf-author-avatar-remove" href="javascript:;" data-attachment_id="%d" data-field_id="%s" data-user_id="%d"><i class="fa fa-close"></i></a>
							<input type="hidden" name="%s" value="%s">
						</div>
					</li>';
				
		$src  = wp_get_attachment_image_src( $id, 'appointy-300x300' );
		$src  = $src[0];
				
		return sprintf(
					$li,
					esc_attr($id),
					esc_url($src),
					esc_attr($title_delete), esc_attr($id), 'useravatar', esc_attr($user_id), 'useravatarid', esc_attr($id)
				);		
	}
	
	/* Default Upload */
	public static function save_default_upload( $id = 0, $field_id = 0 )
	{
		global $wpdb;	
		
		$title_delete = apply_filters( 'rwmb_image_delete_string', _x( 'Delete', 'image upload', 'appointy' ) );
		
		$src  = self::get_icon_for_attachment($id,'appointy-300x300');
		
		
		$filename = basename ( get_attached_file( $id ) );
		
		if($field_id == 'identities')
		{
		$li = '<li id="item_%s">
						<img src="%s" />
						<span class="sf-attachment-filename">%s</span>
						<span class="sf-attachment-download"><a href="'.get_permalink( $id ).'?attachment_id=%d&download_file=1" class="site-button-outline button-sm"><i class="fa fa-download"></i> '.esc_html__('Download','appointy').'</a></span>
						<span class="sf-author-avatar-remove sk-delete-file" data-attachment_id="%s"><i class="fa fa-close"></i></span>
						<input type="hidden" name="%s[]" value="%s">
					</li>';
		
		return sprintf(
					$li,
					esc_attr($id),
					esc_url($src),
					esc_attr($filename),
					esc_attr($id),
					esc_attr($id), 
					$field_id, esc_attr($id)
				);
				
		}else
		{
		$li = '<li id="item_%s">
						<img src="%s" />
						<span class="sf-author-avatar-remove sk-delete-file" data-attachment_id="%s"><i class="fa fa-close"></i></span>
						<input type="hidden" name="%s[]" value="%s">
					</li>';
		
		return sprintf(
					$li,
					esc_attr($id),
					esc_url($src),
					esc_attr($id), 
					$field_id, esc_attr($id)
				);
				
		}			
	}
	
	/* Get icon for attachments */
	public static function get_icon_for_attachment($post_id,$size = 'medium') {
  
		$type = get_post_mime_type($post_id);
		
		switch ($type) {
		case 'image/jpeg':
		case 'image/png':
		case 'image/gif':
		  $src = self::get_image_url($post_id,$size);
		  return $src;
		  break;
		case 'application/pdf':
		  return APPOINTY_IMAGE_URL.'file-icon/pdf.png';
		  break;
		case 'application/msword':
		  return APPOINTY_IMAGE_URL.'file-icon/doc.png';
		  break;
		case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':
		  return APPOINTY_IMAGE_URL.'file-icon/doc.png';
		  break;
		case 'application/vnd.ms-excel':
		  return APPOINTY_IMAGE_URL.'file-icon/xls.png';
		  break;
		case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
		  return APPOINTY_IMAGE_URL.'file-icon/xls.png';
		  break;
		case 'application/vnd.ms-powerpoint':
		  return APPOINTY_IMAGE_URL.'file-icon/ppt.png';
		  break;
		case 'application/vnd.openxmlformats-officedocument.presentationml.presentation':
		  return APPOINTY_IMAGE_URL.'file-icon/ppt.png';
		  break;     
		default:
		  return APPOINTY_IMAGE_URL.'file-icon/text.png';
		  break;
		}
	}
	
	/* Delete file */
	public static function delete_requested_file()
	{
		global $wpdb;
		$current_user = wp_get_current_user(); 
		$field_id      = isset( $_POST['field_id'] ) ? $_POST['field_id'] : '';
		$attachment_id = isset( $_POST['attachment_id'] ) ? intval( $_POST['attachment_id'] ) : 0;
		$user_id = isset( $_POST['user_id'] ) ? intval( $_POST['user_id'] ) : 0;
		
		$ok = wp_delete_attachment( $attachment_id );
		
		if ( $ok ) {
			if($field_id == 'useravatar') {
				delete_user_meta($user_id, $wpdb->get_blog_prefix().'user_avatar');
			}
			wp_send_json_success();
			
		} else {
			wp_send_json_error( esc_html__( 'Error: Cannot delete file', 'appointy' ) );
		}
	}
	
	/* Get attachment url by attachment id */
	public static function get_image_url($attachmentid,$size = 'thumbnail') {
		if($attachmentid > 0) {
			$src  = wp_get_attachment_image_src( $attachmentid, $size );
			$src  = (!empty($src[0])) ? $src[0] : '';
			
			$src = (!empty($src)) ? $src : self::get_image_placeholder();
			
			return $src;
		}
	}
	
	/* Get image placeholder */
	public static function get_avatar_placeholder() {
		$placeholder = APPOINTY_IMAGE_URL.'default-avatar.jpg';
		
		return $placeholder;
	}
	
	/* Get image placeholder */
	public static function get_image_placeholder() {
		$placeholder = APPOINTY_IMAGE_URL.'image-placeholder.jpg';
		
		return $placeholder;
	}
}
new Appointy_Manage_Uploads();