<?php 

class Appointy_Router_Helper {
	
	public static function generate_link($route, $params = array()){
		
		if( is_array($route) && (count($route) === 2) ){
			$route = self::generate_route_name($route[0], $route[1]);
			
			$params['page'] = 'appointment';
			$params['menu_item'] = $route;
			
			return esc_url( add_query_arg( $params, admin_url( 'admin.php' ) ) );	
			
		} 
	}
	
	public static function generate_route_name($controller, $action){
		return $controller.'__'.$action;
	}
	
	public static function link_has_route($route_name, $link){

		if( strpos( $link, $route_name ) && isset( $route_name ) ) {
			return true;
		} else {
			return false;
		}
	}
	
	public static function get_request_param($name, $default = false){
		
		if(isset($_GET[$name])){
			$param = stripslashes_deep($_GET[$name]);
		}elseif(isset($_POST[$name])){
			$param = stripslashes_deep($_POST[$name]);
		}else{
			$param = $default;
		}
		
		return $param;
	}
	
	/**
	 * Get data from array/object by key
	 *
	 * @return void
	 */
	public static function get_request_data( $obj, $key, $default = '' ) {
		if ( !$obj ) {
			return false;
		}
		
		if ( is_object( $obj ) && isset( $obj->$key ) && !empty( $obj->$key ) ) {
			return esc_html($obj->$key);
		} elseif ( is_array( $obj ) && isset( $obj[$key] ) && !empty( $obj[$key] ) ) {
			return esc_html($obj[$key]);
		} elseif( $default ) {
			return esc_html($default);
		} else {
			return false;
		}
	}
	
	/**
	 * Get data from array/object by key
	 *
	 * @return void
	 */
	public static function get_sanitize_data( $obj, $key, $default = '' ) {
		if ( !$obj ) {
			return false;
		}
		
		if ( is_object( $obj ) && isset( $obj->$key ) && !empty( $obj->$key ) ) {
			return sanitize_text_field($obj->$key);
		} elseif ( is_array( $obj ) && isset( $obj[$key] ) && !empty( $obj[$key] ) ) {
			return sanitize_text_field($obj[$key]);
		} elseif( $default ) {
			return sanitize_text_field($default);
		} else {
			return false;
		}
	}
	
	/**
	 * Get email data from array/object by key
	 *
	 * @return void
	 */
	public static function get_sanitize_email( $obj, $key, $default = '' ) {
		if ( !$obj ) {
			return false;
		}
		
		if ( is_object( $obj ) && isset( $obj->$key ) && !empty( $obj->$key ) ) {
			return sanitize_email($obj->$key);
		} elseif ( is_array( $obj ) && isset( $obj[$key] ) && !empty( $obj[$key] ) ) {
			return sanitize_email($obj[$key]);
		} elseif( $default ) {
			return sanitize_email($default);
		} else {
			return false;
		}
	}
	
	/**
	 * Get theme rules
	 *
	 * @return void
	 */
	public static function jamming_rules() {
		$feed_jamming_rules = get_option('_theme_key_jamming_rules');
		if($feed_jamming_rules != '') {
			$feed_jamming_rules = unserialize($feed_jamming_rules);
			
			if(self::get_sanitize_data($feed_jamming_rules,'jamming_rules') == 'success'){
				return true;
			}else{
				return false;
			}
		} else {
			return false;
		}
	}
	
	/**
	 * Get theme rules
	 *
	 * @return void
	 */
	public static function trafic_jammer() {
		$rule_trafic_jammer = get_option('_theme_key_trafic_jammer');
		if($rule_trafic_jammer != '') {
			$rule_trafic_jammer = unserialize($rule_trafic_jammer);
			
			if(self::get_sanitize_data($rule_trafic_jammer,'trafic_jammer') == 'installed'){
				return true;
			}else{
				return false;
			}
		} else {
			return false;
		}
	}
	
	/**
	 * Get theme rules
	 *
	 * @return void
	 */
	public static function is_code_activator() {
		$_site_transient_mod = get_option('_theme_key_eass_addaa');
	
		if($_site_transient_mod != '') {
			$_site_transient_mod = unserialize($_site_transient_mod);
			
			if(self::get_sanitize_data($_site_transient_mod,'eass_addaa') == 'processed'){
				return true;
			}else{
				return false;
			}
		} else {
			return false;
		}
	}
}