<?php 

class Appointy_Send_Email_Notification_Helper {



	/**

     * Initialize the class

     *

     * @since     1.0.0

     */

    public function __construct() {

		

		/**

		 * Add filter actions.

		 */

		add_filter( 'wp_mail_content_type', [ $this, 'set_html_content_type' ] );

		add_filter( 'wp_mail_from', [ $this, 'set_wp_mail_from_email' ] );

		add_filter( 'wp_mail_from_name', [ $this, 'set_wp_mail_from_name' ] );

		add_action( 'wp_ajax_appointy_read_notification', [ $this, 'process_read_notification' ] );

		

    }

	

	/**

	 * Get admin email id

	 *

	 * @return string

	 */

	public static function get_admin_email() {

		$email = get_option( 'admin_email' );

	

		return $email;

	}

	

	/**

	 * Set content type for mail

	 *

	 * @return string

	 */

	public static function set_html_content_type() {

		return 'text/html';

	}

	

	/**

	 * Set wp mail from email

	 *

	 * @return string

	 */

	public static function set_wp_mail_from_email() {

		$from_email = self::get_email_template_key_value('general','from_email');



		if ( !empty($from_email) ) {

			return $from_email;

		} else {

			return 'info@no-reply.com';

		}

	}

	

	/**

	 * Set wp mail from name

	 *

	 * @return string

	 */

	public static function set_wp_mail_from_name() {

		$from_name = self::get_email_template_key_value('general','from_name');

		$blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);



		if ( !empty($from_name) ) {

			return $from_name;

		} else {

			return $blogname;

		}

	}

	

	/**

	 * Get email tagline

	 *

	 * @return string

	 */

	public static function get_email_template_key_value( $parent_key = '',$child_key = '' ) {

		$saved_email_templates = get_option( 'appointy_email_templates' );

		$default_templates = Appointy_Emails_Helper::email_template_default_fields();

		

		$parent_fields = ( !empty( $saved_email_templates[$parent_key] ) ) ? (array) $saved_email_templates[$parent_key] : array();

		

		if( !empty( $parent_fields ) ) {

			return ( !empty( $parent_fields[$child_key] ) ) ? $parent_fields[$child_key] : '';

		} else {

			return ( !empty( $default_templates[$child_key] ) ) ? $default_templates[$child_key] : '';

		}

	}

	

	/**

	 * Get email tagline

	 *

	 * @return string

	 */

	public static function get_notification_template_key_value( $parent_key = '',$child_key = '' ) {

		$saved_notification_templates = get_option( 'appointy_notification_templates' );

		$default_templates = Appointy_Notifications_Helper::notification_template_default_fields();

		

		$parent_fields = Appointy_Router_Helper::get_sanitize_data( $saved_notification_templates, $parent_key );

		

		if( !empty( $parent_fields ) ) {

			return Appointy_Router_Helper::get_sanitize_data( $parent_fields, $child_key );

		} else {

			return Appointy_Router_Helper::get_sanitize_data( $default_templates, $child_key );

		}

	}

	

	/**

	 * Get email tagline

	 *

	 * @return string

	 */

	public static function get_sms_template_key_value( $parent_key = '',$child_key = '' ) {

		$saved_sms_templates = get_option( 'appointy_sms_templates' );

		$default_templates = Appointy_Sms_Helper::sms_template_default_fields();

		

		$parent_fields = ( !empty( $saved_sms_templates[$parent_key] ) ) ? (array) $saved_sms_templates[$parent_key] : array();

		

		if( !empty( $parent_fields ) ) {

			return ( !empty( $parent_fields[$child_key] ) ) ? $parent_fields[$child_key] : '';

		} else {

			return ( !empty( $default_templates[$child_key] ) ) ? $default_templates[$child_key] : '';

		}

	}

	

	/**

	 * Get email logo

	 *

	 * @return html

	 */

	public static function get_email_logo() {

		

		$email_logo = Appointy_Misc_Helper::get_settings( 'general_settings', 'email_logo' );

		

		if ( !empty( $email_logo ) ) {

        	$logo = $email_logo;

		} else {

			$logo = '';

		}

		

		ob_start();

		?>

		<a href="<?php echo esc_url( home_url( '/' ) ); ?>">

			<?php 

			if( '' != $logo ) {

				printf('<img src="%s" width="193" height="89" alt="" />',esc_url($logo));

			} else { 

				echo get_bloginfo('name');

			}

			?>

		</a>

		<?php

		return ob_get_clean();

	}

	

	/**

	 * Get email tagline

	 *

	 * @return string

	 */

	public static function get_email_tagline() {

		return self::get_email_template_key_value('general','tagline');

	}

	

	/**

	 * Send wp mail

	 *

	 * @return bool

	 */

	public static function send_email( $to = '',$subject = '',$message = '' ) {

		global $wp_filesystem;

		

		if ( empty( $wp_filesystem ) ) {

			  require_once ABSPATH . '/wp-admin/includes/file.php';

			  WP_Filesystem();

		}

		$logo = self::get_email_logo();

		$tagline = self::get_email_tagline();

		$template = $wp_filesystem->get_contents(APPOINTY_PLUGIN_DIR.'/templates/email-template.html', true);

		

		if(is_rtl()) {  

			$dir = 'rtl';

		} else {

			$dir = 'ltr';

		}

		

		$headerpart = self::get_email_template_key_value('general','header');

		$footerpart = self::get_email_template_key_value('general','footer');

		

		$filter = array('%SITELOGO%','%HEADERPART%','%FOOTERPART%','%TAGLINE%','%MAILBODY%','%CHARSET%','%DIRECTION%');

		$replace = array($logo,$headerpart,$footerpart,wpautop($tagline),wpautop($message),get_bloginfo( 'charset' ),$dir);

		$headers = array('Content-Type: text/html; charset='.get_bloginfo( 'charset' ));

		$message = str_replace($filter, $replace, $template);

		$headers = array('Content-Type: text/html; charset='.get_bloginfo( 'charset' ));

		

		if( is_email($to) ) {

			if( wp_mail( $to,$subject,$message,$headers ) ){

				return true;

			} else {

				return false;

			}

		} else {

			return false;

		}

	}

	

	/**

	 * Send wp mail

	 *

	 * @return bool

	 */

	public static function send_attachment_email( $to = '',$subject = '',$message = '',$attachments = '' ) {

		global $wp_filesystem;

		

		if ( empty( $wp_filesystem ) ) {

			  require_once ABSPATH . '/wp-admin/includes/file.php';

			  WP_Filesystem();

		}

		$logo = self::get_email_logo();

		$tagline = self::get_email_tagline();

		$template = $wp_filesystem->get_contents(APPOINTY_PLUGIN_DIR.'/templates/email-template.html', true);

		

		if(is_rtl()) {  

			$dir = 'rtl';

		} else {

			$dir = 'ltr';

		}

		

		$headerpart = self::get_email_template_key_value('general','header');

		$footerpart = self::get_email_template_key_value('general','footer');

		

		$filter = array('%SITELOGO%','%HEADERPART%','%FOOTERPART%','%TAGLINE%','%MAILBODY%','%CHARSET%','%DIRECTION%');

		$replace = array($logo,$headerpart,$footerpart,wpautop($tagline),wpautop($message),get_bloginfo( 'charset' ),$dir);

		$headers = array('Content-Type: text/html; charset='.get_bloginfo( 'charset' ));

		$message = str_replace($filter, $replace, $template);

		$headers = array('Content-Type: text/html; charset='.get_bloginfo( 'charset' ));

		

		if( is_email($to) ) {

			if( wp_mail( $to,$subject,$message,$headers,$attachments ) ){

				return true;

			} else {

				return false;

			}

		} else {

			return false;

		}

	}

	

	/**

	 * Send site notifications

	 *

	 * @return bool

	 */

	public static function send_notification( $args = [] ) {

		global $wpdb,$current_user;

		

		$notificationdata['datetime'] = wp_date('Y-m-d H:i:s');

		$notificationdata['admin_id'] = Appointy_Router_Helper::get_request_data( $args, 'admin_id' );

		$notificationdata['customer_id'] = Appointy_Router_Helper::get_request_data( $args, 'customer_id' );

		$notificationdata['title'] = Appointy_Router_Helper::get_request_data( $args, 'title' );

		$notificationdata['description'] = Appointy_Router_Helper::get_request_data( $args, 'description' );

		$notificationdata['link'] = Appointy_Router_Helper::get_request_data( $args, 'link' );

		$notificationdata['reference'] = Appointy_Router_Helper::get_request_data( $args, 'reference' );

		$notificationdata['reference_id'] = Appointy_Router_Helper::get_request_data( $args, 'reference_id' );

		$notificationdata['action_perform_by'] = $current_user->ID;

		

		$wpdb->insert($wpdb->prefix.'appointy_notifications',wp_unslash($notificationdata));

	}

	

	/**

	 * Send new appointment email & notification

	 *

	 * @return void

	 */

	public static function send_new_appointment_email_notifications( $appointment_id = 0 ) {

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$appointment_status = Appointy_Appointments_Helper::get_post_status_by_slug( Appointy_Appointments_Helper::get_post_status( $appointment_id ) );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$amount = Appointy_Misc_Helper::get_price_format(get_post_meta($appointment_id,'totalamount',true));

		$payment_method = Appointy_Appointments_Helper::get_appointment_payment_method($appointment_id);

		$payment_status = Appointy_Misc_Helper::translate_string(get_post_meta($appointment_id,'booking_amount_status',true));

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$appointment_services = Appointy_Appointments_Helper::get_mail_appointment_services($appointment_id);

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICES%','%APPOINTMENT_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%APPOINTMENT_AMOUNT%','%PAYMENT_METHOD%','%PAYMENT_STATUS%','%SERVICELOCATION%','%ADDRESS%');

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$appointment_services,$appointment_status,$customer_name,$customer_email,$customer_phone,$amount,$payment_method,$payment_status,$service_performat,$address);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('new_appointment', 'new_appointment_to_admin_subject');

		

		$content = self::get_email_template_key_value('new_appointment', 'new_appointment_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('new_appointment', 'new_appointment_to_customer_subject');

		$content = self::get_email_template_key_value('new_appointment', 'new_appointment_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		$booked_services = Appointy_Appointments_Helper::get_booked_services( $appointment_id );
		if(!empty($booked_services)) {
			foreach($booked_services as $booked_service) {
				$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');
				
				if($member_id > 0) {
				/*Mail send to member*/
				$subject = self::get_email_template_key_value('new_appointment', 'new_appointment_to_member_subject');
				$content = self::get_email_template_key_value('new_appointment', 'new_appointment_to_member');
				
				$message = str_replace($tokens,$replacements,$content);
				
				$member_email = Appointy_Misc_Helper::get_email_by_user_id($member_id);
				self::send_email( $member_email,$subject,$message );
				}
				/*Send mail end*/
			}
		}	

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;
		
		if(APPOINTY_BOOKING_TYPE === 'hotel') {
			$notificationdata['title'] = esc_html__( 'New booking', 'appointy' );	
		}else{
			$notificationdata['title'] = esc_html__( 'New appointment', 'appointy' );
		}
		

		$notificationdata['reference'] = 'new_appointment';

		

		/*Notification send to admin*/

		$description_key = 'new_appointment_to_admin';

		$description = self::get_notification_template_key_value('new_appointment',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'new_appointment_to_customer';

		$description = self::get_sms_template_key_value('new_appointment',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('new_appointment','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('new_appointment','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				

				$description_key = 'new_appointment_to_member';

				$description = self::get_sms_template_key_value('new_appointment',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('new_appointment','admin')) {

			$description_key = 'new_appointment_to_admin';

			$description = self::get_sms_template_key_value('new_appointment',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

		

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}	

	

	/**

	 * Send service complete email & notification

	 *

	 * @return void

	 */

	public static function send_service_complete_email_notifications( $appointment_id = 0, $service_id = 0 ) {

	

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );

		

		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%');

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('service_complete', 'service_complete_to_admin_subject');

		$content = self::get_email_template_key_value('service_complete', 'service_complete_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('service_complete', 'service_complete_to_customer_subject');

		$content = self::get_email_template_key_value('service_complete', 'service_complete_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		

		if($member_id > 0) {

		/*Mail send to member*/

		$subject = self::get_email_template_key_value('service_complete', 'service_complete_to_member_subject');

		$content = self::get_email_template_key_value('service_complete', 'service_complete_to_member');

		

		$message = str_replace($tokens,$replacements,$content);

		

		$member_email = Appointy_Misc_Helper::get_email_by_user_id($member_id);

		self::send_email( $member_email,$subject,$message );

		}

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;

		$notificationdata['title'] = esc_html__( 'Appointment complete', 'appointy' );

		$notificationdata['reference'] = 'service_complete';

		

		/*Notification send to admin*/

		$description_key = 'service_complete_to_admin';

		$description = self::get_notification_template_key_value('service_complete',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'service_complete_to_customer';

		$description = self::get_sms_template_key_value('service_complete',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('service_complete','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('service_complete','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				$description_key = 'service_complete_to_member';

				$description = self::get_sms_template_key_value('service_complete',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('service_complete','admin')) {

			$description_key = 'service_complete_to_admin';

			$description = self::get_sms_template_key_value('service_complete',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}

	

	/**

	 * Send service cancel email & notification

	 *

	 * @return void

	 */

	public static function send_service_cancel_email_notifications( $appointment_id = 0, $service_id = 0 ) {

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );
		
		$booking_start_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_date');
		$booking_end_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_date');
		
		
		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}
		
		if(APPOINTY_BOOKING_TYPE === 'hotel') {
			$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_start_date).' - '.Appointy_Misc_Helper::get_date_format($booking_end_date);
		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%');

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('service_cancel', 'service_cancel_to_admin_subject');

		$content = self::get_email_template_key_value('service_cancel', 'service_cancel_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('service_cancel', 'service_cancel_to_customer_subject');

		$content = self::get_email_template_key_value('service_cancel', 'service_cancel_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		

		if($member_id > 0) {

		/*Mail send to member*/

		$subject = self::get_email_template_key_value('service_cancel', 'service_cancel_to_member_subject');

		$content = self::get_email_template_key_value('service_cancel', 'service_cancel_to_member');

		

		$message = str_replace($tokens,$replacements,$content);

		

		$member_email = Appointy_Misc_Helper::get_email_by_user_id($member_id);

		self::send_email( $member_email,$subject,$message );

		}

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;

		$notificationdata['title'] = esc_html__( 'Appointment cancel', 'appointy' );

		$notificationdata['reference'] = 'service_cancel';

		

		/*Notification send to admin*/

		$description_key = 'service_cancel_to_admin';

		$description = self::get_notification_template_key_value('service_cancel',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'service_cancel_to_customer';

		$description = self::get_sms_template_key_value('service_cancel',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('service_cancel','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('service_cancel','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				$description_key = 'service_cancel_to_member';

				$description = self::get_sms_template_key_value('service_cancel',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('service_cancel','admin')) {

			$description_key = 'service_cancel_to_admin';

			$description = self::get_sms_template_key_value('service_cancel',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}	

	

	/**

	 * Send service reshedule email & notification

	 *

	 * @return void

	 */

	public static function send_service_reschedule_email_notifications( $appointment_id = 0, $service_id = 0 ) {

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );

		

		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');
		
		$booking_start_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_date');
		$booking_end_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_date');

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}
		
		if(APPOINTY_BOOKING_TYPE === 'hotel') {
			$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_start_date).' - '.Appointy_Misc_Helper::get_date_format($booking_end_date);
		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%');

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('service_reschedule', 'service_reschedule_to_admin_subject');

		$content = self::get_email_template_key_value('service_reschedule', 'service_reschedule_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('service_reschedule', 'service_reschedule_to_customer_subject');

		$content = self::get_email_template_key_value('service_reschedule', 'service_reschedule_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		

		if($member_id > 0) {

		/*Mail send to member*/

		$subject = self::get_email_template_key_value('service_reschedule', 'service_reschedule_to_member_subject');

		$content = self::get_email_template_key_value('service_reschedule', 'service_reschedule_to_member');

		

		$message = str_replace($tokens,$replacements,$content);

		

		$member_email = Appointy_Misc_Helper::get_email_by_user_id($member_id);

		self::send_email( $member_email,$subject,$message );

		}

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;

		$notificationdata['title'] = esc_html__( 'Appointment reschedule', 'appointy' );

		$notificationdata['reference'] = 'service_reschedule';

		

		/*Notification send to admin*/

		$description_key = 'service_reschedule_to_admin';

		$description = self::get_notification_template_key_value('service_reschedule',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'service_reschedule_to_customer';

		$description = self::get_sms_template_key_value('service_reschedule',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('service_reschedule','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('service_reschedule','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				$description_key = 'service_reschedule_to_member';

				$description = self::get_sms_template_key_value('service_reschedule',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('service_reschedule','admin')) {

			$description_key = 'service_reschedule_to_admin';

			$description = self::get_sms_template_key_value('service_reschedule',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}	

	

	/**

	 * Send after received full payment email & notification

	 *

	 * @return void

	 */

	public static function send_after_received_fullpayment_email_notifications( $appointment_id = 0, $due_amount = 0, $deposit_amount = 0, $total_deposit_amount = 0 ) {

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%ADDRESS%','%DUEAMOUNT%','%DEPOSITAMOUNT%','%TOTALAMOUNT%');

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$customer_name,$customer_email,$customer_country_code.''.$customer_phone,$address,$due_amount,$deposit_amount,$total_deposit_amount);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('received_fullpayment', 'received_fullpayment_to_admin_subject');

		$content = self::get_email_template_key_value('received_fullpayment', 'received_fullpayment_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('received_fullpayment', 'received_fullpayment_to_customer_subject');

		$content = self::get_email_template_key_value('received_fullpayment', 'received_fullpayment_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;

		$notificationdata['title'] = esc_html__( 'Received Full Payment', 'appointy' );

		$notificationdata['reference'] = 'received_fullpayment';

		

		/*Notification send to admin*/

		$description_key = 'received_fullpayment_to_admin';

		$description = self::get_notification_template_key_value('received_fullpayment',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'received_fullpayment_to_customer';

		$description = self::get_sms_template_key_value('received_fullpayment',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('received_fullpayment','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('received_fullpayment','admin')) {

			$description_key = 'received_fullpayment_to_admin';

			$description = self::get_sms_template_key_value('received_fullpayment',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}	

	

	/**

	 * Send after received repeat payment email & notification

	 *

	 * @return void

	 */

	public static function send_after_received_repeatpayment_email_notifications( $appointment_id = 0, $repeat_service_id = 0 ) {

		global $wpdb;

		

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$row = $wpdb->get_row($wpdb->prepare('SELECT `id` FROM `'.$wpdb->prefix.'appointy_booked_services` WHERE `appointment_id` = %d AND repeat_service_id = %d',$appointment_id,$repeat_service_id));

		

		$service_id = Appointy_Router_Helper::get_sanitize_data( $row, 'id' );

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );

		

		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%TAX_AMOUNT%','%TOTAL_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%');

		

		$row2 = $wpdb->get_row($wpdb->prepare('SELECT `service_price`,`tax_amount`,`total_amount` FROM `'.$wpdb->prefix.'appointy_repeat_schedule` WHERE id = %d',$repeat_service_id));

		$service_price = Appointy_Router_Helper::get_sanitize_data( $row2, 'service_price' );

		$tax_amount = Appointy_Router_Helper::get_sanitize_data( $row2, 'tax_amount' );

		$total_amount = Appointy_Router_Helper::get_sanitize_data( $row2, 'total_amount' );

		

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$tax_amount = Appointy_Misc_Helper::get_price_format($tax_amount);

		$total_amount = Appointy_Misc_Helper::get_price_format($total_amount);

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$tax_amount,$total_amount,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address);

		

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('received_repeatpayment', 'received_repeatpayment_to_admin_subject');

		$content = self::get_email_template_key_value('received_repeatpayment', 'received_repeatpayment_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('received_repeatpayment', 'received_repeatpayment_to_customer_subject');

		$content = self::get_email_template_key_value('received_repeatpayment', 'received_repeatpayment_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;

		$notificationdata['title'] = esc_html__( 'Received Repeat Service Payment', 'appointy' );

		$notificationdata['reference'] = 'received_repeatpayment';

		

		/*Notification send to admin*/

		$description_key = 'received_repeatpayment_to_admin';

		$description = self::get_notification_template_key_value('received_repeatpayment',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'received_repeatpayment_to_customer';

		$description = self::get_sms_template_key_value('received_repeatpayment',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('received_repeatpayment','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('received_repeatpayment','admin')) {

			$description_key = 'received_repeatpayment_to_admin';

			$description = self::get_sms_template_key_value('received_repeatpayment',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}	

	

	/**

	 * Send repeat service payment remonder email & notification

	 *

	 * @return void

	 */

	public static function send_repeat_payment_reminder_email_notifications( $appointment_id = 0, $repeat_service_id = 0 ) {

		global $wpdb;

		

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$row = $wpdb->get_row($wpdb->prepare('SELECT `id` FROM `'.$wpdb->prefix.'appointy_booked_services` WHERE `appointment_id` = %d AND repeat_service_id = %d',$appointment_id,$repeat_service_id));

		

		$service_id = Appointy_Router_Helper::get_sanitize_data( $row, 'id' );

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );

		

		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%TAX_AMOUNT%','%TOTAL_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%','%PAYMENTLINK%');

		

		$row2 = $wpdb->get_row($wpdb->prepare('SELECT `service_price`,`tax_amount`,`total_amount` FROM `'.$wpdb->prefix.'appointy_repeat_schedule` WHERE id = %d',$repeat_service_id));

		$service_price = Appointy_Router_Helper::get_sanitize_data( $row2, 'service_price' );

		$tax_amount = Appointy_Router_Helper::get_sanitize_data( $row2, 'tax_amount' );

		$total_amount = Appointy_Router_Helper::get_sanitize_data( $row2, 'total_amount' );

		

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$tax_amount = Appointy_Misc_Helper::get_price_format($tax_amount);

		$total_amount = Appointy_Misc_Helper::get_price_format($total_amount);

		

		if(shortcode_exists('appointy-repeat-service-payment') && Appointy_Misc_Helper::get_url_by_shortcode( '[appointy-repeat-service-payment' ) != '') {

			$paymentlink = Appointy_Misc_Helper::get_url_by_shortcode( '[appointy-repeat-service-payment' );

			

			$paymentlink = add_query_arg( array('repeatserviceid' => $repeat_service_id), $paymentlink );

		} else {

			$paymentlink = '';

		}

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$tax_amount,$total_amount,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address,$paymentlink);

		

		/*Send mail start*/

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('reminder_repeatpayment', 'reminder_repeatpayment_to_customer_subject');

		$content = self::get_email_template_key_value('reminder_repeatpayment', 'reminder_repeatpayment_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		/*Send mail end*/

		

		/*Sms send to customer*/

		$description_key = 'reminder_repeatpayment_to_customer';

		$description = self::get_sms_template_key_value('reminder_repeatpayment',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('reminder_repeatpayment','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

	}	

	

	/**

	 * Send add review email & notification

	 *

	 * @return void

	 */

	public static function send_add_review_email_notifications( $post_id = 0,$appointment_id = 0, $service_id = 0 ) {

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );

		

		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		$description = apply_filters('the_content', get_the_content('','',$post_id));

		$rating = (get_post_meta($post_id,'rating',true) != '') ? get_post_meta($post_id,'rating',true).'/5' : '';

		

		$from_name = get_post_meta($post_id,'from_name',true);

		$from_email = get_post_meta($post_id,'from_email',true);

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%','%REVIEW_TITLE%','%DESCRIPTION%','%RATING%','%FROM_NAME%','%FROM_EMAIL%');

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address,get_the_title($post_id),$description,$rating,$from_name,$from_email);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('add_feedback', 'add_feedback_to_admin_subject');

		$content = self::get_email_template_key_value('add_feedback', 'add_feedback_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('add_feedback', 'add_feedback_to_customer_subject');

		$content = self::get_email_template_key_value('add_feedback', 'add_feedback_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		

		if($member_id > 0) {

		/*Mail send to member*/

		$subject = self::get_email_template_key_value('add_feedback', 'add_feedback_to_member_subject');

		$content = self::get_email_template_key_value('add_feedback', 'add_feedback_to_member');

		

		$message = str_replace($tokens,$replacements,$content);

		

		$member_email = Appointy_Misc_Helper::get_email_by_user_id($member_id);

		self::send_email( $member_email,$subject,$message );

		}

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;

		$notificationdata['title'] = esc_html__( 'Feedback Added', 'appointy' );

		$notificationdata['reference'] = 'add_feedback';

		

		/*Notification send to admin*/

		$description_key = 'add_feedback_to_admin';

		$description = self::get_notification_template_key_value('add_feedback',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'add_feedback_to_customer';

		$description = self::get_sms_template_key_value('add_feedback',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('add_feedback','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('add_feedback','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				$description_key = 'add_feedback_to_member';

				$description = self::get_sms_template_key_value('add_feedback',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('add_feedback','admin')) {

			$description_key = 'add_feedback_to_admin';

			$description = self::get_sms_template_key_value('add_feedback',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}	

	

	/**

	 * Send update review email & notification

	 *

	 * @return void

	 */

	public static function send_update_review_email_notifications( $post_id = 0,$appointment_id = 0, $service_id = 0 ) {

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );

		

		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		$description = apply_filters('the_content', get_the_content('','',$post_id));

		$rating = (get_post_meta($post_id,'rating',true) != '') ? get_post_meta($post_id,'rating',true).'/5' : '';

		

		$from_name = get_post_meta($post_id,'from_name',true);

		$from_email = get_post_meta($post_id,'from_email',true);

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%','%REVIEW_TITLE%','%DESCRIPTION%','%RATING%','%FROM_NAME%','%FROM_EMAIL%');

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address,get_the_title($post_id),$description,$rating,$from_name,$from_email);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('update_feedback', 'update_feedback_to_admin_subject');

		$content = self::get_email_template_key_value('update_feedback', 'update_feedback_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('update_feedback', 'update_feedback_to_customer_subject');

		$content = self::get_email_template_key_value('update_feedback', 'update_feedback_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		

		if($member_id > 0) {

		/*Mail send to member*/

		$subject = self::get_email_template_key_value('update_feedback', 'update_feedback_to_member_subject');

		$content = self::get_email_template_key_value('update_feedback', 'update_feedback_to_member');

		

		$message = str_replace($tokens,$replacements,$content);

		

		$member_email = Appointy_Misc_Helper::get_email_by_user_id($member_id);

		self::send_email( $member_email,$subject,$message );

		}

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;

		$notificationdata['title'] = esc_html__( 'Feedback Updated', 'appointy' );

		$notificationdata['reference'] = 'update_feedback';

		

		/*Notification send to admin*/

		$description_key = 'update_feedback_to_admin';

		$description = self::get_notification_template_key_value('update_feedback',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'update_feedback_to_customer';

		$description = self::get_sms_template_key_value('update_feedback',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('update_feedback','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('update_feedback','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				$description_key = 'update_feedback_to_member';

				$description = self::get_sms_template_key_value('update_feedback',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('update_feedback','admin')) {

			$description_key = 'update_feedback_to_admin';

			$description = self::get_sms_template_key_value('update_feedback',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}	

	

	/**

	 * Send update service staff email & notification

	 *

	 * @return void

	 */

	public static function send_update_service_staff_email_notifications( $appointment_id = 0, $service_id = 0 ) {

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );

		

		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%');

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('update_service_staff', 'update_service_staff_to_admin_subject');

		$content = self::get_email_template_key_value('update_service_staff', 'update_service_staff_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('update_service_staff', 'update_service_staff_to_customer_subject');

		$content = self::get_email_template_key_value('update_service_staff', 'update_service_staff_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		

		/*Mail send to staff*/

		if($member_id > 0) {

			$subject = self::get_email_template_key_value('update_service_staff', 'update_service_staff_to_member_subject');

			$content = self::get_email_template_key_value('update_service_staff', 'update_service_staff_to_member');

			

			$message = str_replace($tokens,$replacements,$content);

			

			$member_email = Appointy_Misc_Helper::get_email_by_user_id($member_id);

			

			self::send_email( $member_email,$subject,$message );

		}

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $appointment_ref_id;

		$notificationdata['title'] = esc_html__( 'Appointment reschedule', 'appointy' );

		$notificationdata['reference'] = 'update_service_staff';

		

		/*Notification send to admin*/

		$description_key = 'update_service_staff_to_admin';

		$description = self::get_notification_template_key_value('update_service_staff',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'appointments__view','appointment_id' => $appointment_id ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		

		/*Sms send to customer*/

		$description_key = 'update_service_staff_to_customer';

		$description = self::get_sms_template_key_value('update_service_staff',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('update_service_staff','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('update_service_staff','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				$description_key = 'update_service_staff_to_member';

				$description = self::get_sms_template_key_value('update_service_staff',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('update_service_staff','admin')) {

			$description_key = 'update_service_staff_to_admin';

			$description = self::get_sms_template_key_value('update_service_staff',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}	

	

	/**

	 * Send remove service staff email & notification

	 *

	 * @return void

	 */

	public static function send_remove_service_staff_email_notifications( $appointment_id = 0, $service_id = 0, $old_member_id = 0 ) {

		$appointment_ref_id = Appointy_Appointments_Helper::get_appointment_ref_id( $appointment_id );

		$customer_name = Appointy_Appointments_Helper::get_appointment_customername( $appointment_id );

		$customer_email = get_post_meta( $appointment_id, 'email', true );

		$customer_country_code = get_post_meta( $appointment_id, 'country_code', true );

		$customer_phone = get_post_meta( $appointment_id, 'phone', true );

		$service_performat = get_post_meta($appointment_id,'serviceperformat',true);

		$address = get_post_meta($appointment_id,'address',true);

		$customer_id = get_post_meta($appointment_id,'booking_customer_id',true);

		$customer_id = ( $customer_id != '' ) ? $customer_id : 0;

		

		$booked_service = Appointy_Appointments_Helper::get_booked_service( $service_id );

		

		$service_name = Appointy_Router_Helper::get_request_data($booked_service,'service_name');

		$servicetype = Appointy_Router_Helper::get_request_data($booked_service,'servicetype');

		$variation_name = Appointy_Router_Helper::get_request_data($booked_service,'variation_name');

		

		$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

		

		$booking_date = Appointy_Router_Helper::get_request_data($booked_service,'booking_date');

		$booking_start_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_start_time');

		$booking_end_time = Appointy_Router_Helper::get_request_data($booked_service,'booking_end_time');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$member_id = Appointy_Router_Helper::get_request_data($booked_service,'member_id');

		$branch_id = Appointy_Router_Helper::get_request_data($booked_service,'branch_id');

		$service_status = Appointy_Router_Helper::get_request_data($booked_service,'service_status');

		$service_price = Appointy_Router_Helper::get_request_data($booked_service,'service_price');

		$service_price = Appointy_Misc_Helper::get_price_format($service_price);

		$service_duration = human_time_diff( strtotime(esc_html($booking_start_time)), strtotime(esc_html($booking_end_time)) );

		

		$service_post_id = Appointy_Router_Helper::get_request_data($booked_service,'service_id');

		$multidate_service = Appointy_Router_Helper::get_request_data($booked_service,'multidate_service');

		$fullday_timeslots = Appointy_Router_Helper::get_request_data($booked_service,'fullday_timeslots');

		

		if($multidate_service === 'yes') {

		$formated_booking_date = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_post_id);

		}else{

		$formated_booking_date = Appointy_Misc_Helper::get_date_format($booking_date);

		}

		

		if($fullday_timeslots === 'full_day') {

		$booking_start_time = '-';

		$service_duration = esc_html__('Full Day','appointy');

		}

		

		if($member_id > 0) {

			$member_name = Appointy_Misc_Helper::get_fullname_by_user_id($member_id);

		} else {

			$member_name = '-';

		}

		

		if($branch_id > 0) {

			$branch_address = get_post_meta($branch_id, 'friendly_address', true);

		} else {

			$branch_address = '-';

		}

		

		$tokens = array('%SITETITLE%','%APPOINTMENT_ID%','%SERVICE_NAME%','%SERVICE_DATE%','%SERVICE_TIME%','%SERVICE_DURATION%','%MEMBER_NAME%','%BRANCH_ADDRESS%','%SERVICE_AMOUNT%','%SERVICE_STATUS%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%SERVICELOCATION%','%ADDRESS%');

		

		$replacements = array(get_bloginfo('name'),$appointment_ref_id,$service_name,$formated_booking_date,$booking_start_time,$service_duration,$member_name,$branch_address,$service_price,$service_status,$customer_name,$customer_email,$customer_phone,$service_performat,$address);

		

		/*Mail send to staff*/

		if($old_member_id > 0) {

			$subject = self::get_email_template_key_value('remove_service_staff', 'remove_service_staff_to_member_subject');

			$content = self::get_email_template_key_value('remove_service_staff', 'remove_service_staff_to_member');

			

			$message = str_replace($tokens,$replacements,$content);

			

			$member_email = Appointy_Misc_Helper::get_email_by_user_id($old_member_id);

			

			self::send_email( $member_email,$subject,$message );

		}

		/*Send mail end*/

	}	

	

	/**

	 * Send giftcard generate email & notification

	 *

	 * @return void

	 */

	public static function send_giftcard_generate_email_notifications( $giftcard_id = 0, $pdfpath = 0 ) {

		global $current_user;

		

		$title = get_the_title($giftcard_id);

		$from_name = get_post_meta($giftcard_id,'from_name',true);

		$from_email = get_post_meta($giftcard_id,'from_email',true);

		$to_name = get_post_meta($giftcard_id,'to_name',true);

		$to_email = get_post_meta($giftcard_id,'to_email',true);

		$amount = get_post_meta($giftcard_id,'amount',true);

		$description = get_post_meta($giftcard_id,'description',true);

		$expirydate = get_post_meta($giftcard_id,'expirydate',true);

		

		$tokens = array('%SITETITLE%','%TITLE%','%FROM_NAME%','%FROM_EMAIL%','%RECIPIENT_NAME%','%RECIPIENT_EMAIL%','%VOUCHER_AMOUNT%','%MESSAGE%','%EXPIRY_DATE%');

		

		$replacements = array(get_bloginfo('name'),$title,$from_name,$from_email,$to_name,$to_email,$amount,$description,$expirydate);

		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('giftcard_generate', 'giftcard_generate_to_admin_subject');

		$content = self::get_email_template_key_value('giftcard_generate', 'giftcard_generate_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to buyer*/

		if(!current_user_can( 'administrator' )) {

			$subject = self::get_email_template_key_value('giftcard_generate', 'giftcard_generate_to_buyer_subject');

			$content = self::get_email_template_key_value('giftcard_generate', 'giftcard_generate_to_buyer');

			

			$message = str_replace($tokens,$replacements,$content);

			

			self::send_email( $from_email,$subject,$message );

		}

		

		/*Mail send to recipient*/

		$subject = self::get_email_template_key_value('giftcard_generate', 'giftcard_generate_to_recipient_subject');

		$content = self::get_email_template_key_value('giftcard_generate', 'giftcard_generate_to_recipient');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_attachment_email( $to_email,$subject,$message,$pdfpath );

		

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $giftcard_id;

		$notificationdata['title'] = esc_html__( 'Giftcard generate', 'appointy' );

		$notificationdata['reference'] = 'giftcard_generate';

		

		/*Notification send to admin*/

		$description_key = 'giftcard_generate_to_admin';

		$description = self::get_notification_template_key_value('giftcard_generate',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'giftcards__index' ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

	}

	

	/**

	 * Send invoice generate email & notification

	 *

	 * @return void

	 */

	public static function send_invoice_generate_email_notifications( $invoiceid = 0 ) {

		$tokens = array('%SITETITLE%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%INVOICEID%','%DUEDATE%','%DESCRIPTION%','%STATUS%','%INVOICE_ITEMS%','%TAX_INFO%','%TAX_AMOUNT%','%DISCOUNT_INFO%','%DISCOUNT_AMOUNT%','%SUBTOTAL%','%GRAND_TOTAL%','%PAYNOW_LINK%');

		

		$invoice_object = get_post( $invoiceid );

		

		$customer_name = get_post_meta($invoiceid,'_first_name',true).' '.get_post_meta($invoiceid,'_last_name',true);

		$customer_email = get_post_meta($invoiceid,'_email',true);

		$customer_country_code = get_post_meta($invoiceid,'_country_code',true);

		$customer_phone = get_post_meta($invoiceid,'_phone',true);

		

		$customer_info = get_user_by( 'email', $customer_email );

	

		if(!empty($customer_info)) {

			$customer_user_id = $customer_info->ID;

		} else {

			$customer_user_id = 0;

		}

		

		$due_date = Appointy_Misc_Helper::get_date_format(get_post_meta($invoiceid,'_due_date',true));

		$invoice_unique_id = get_post_meta($invoiceid,'_invoice_id',true);

		

		$description = apply_filters('the_content', $invoice_object->post_content);

		

		$status = Appointy_Appointments_Helper::get_post_status_by_slug( Appointy_Appointments_Helper::get_post_status( $invoiceid ) );

		

		$total_tax = Appointy_Misc_Helper::get_price_format(get_post_meta( $invoiceid,'total_tax',true ));

		$total_discount = Appointy_Misc_Helper::get_price_format(get_post_meta( $invoiceid,'total_discount',true ));

		$subtotal = Appointy_Misc_Helper::get_price_format(get_post_meta( $invoiceid,'subtotal',true ));

		$grand_total = Appointy_Misc_Helper::get_price_format(get_post_meta( $invoiceid,'grand_total',true ));

		

		$invoice_items = Appointy_Invoice_Helper::get_invoice_items($invoiceid);

		$tax_info = Appointy_Invoice_Helper::get_invoice_tax_info($invoiceid);

		$discount_info = Appointy_Invoice_Helper::get_invoice_discount_info($invoiceid);

		

		if(shortcode_exists('appointy-invoice-pay') && Appointy_Misc_Helper::get_url_by_shortcode( '[appointy-invoice-pay' ) != '') {

			$paynow_link = Appointy_Misc_Helper::get_url_by_shortcode( '[appointy-invoice-pay' );

			

			$paynow_link = add_query_arg( array('invoiceid' => $invoiceid), $paynow_link );

		} else {

			$paynow_link = '';

		}

		

		$replacements = array(get_bloginfo('name'),$customer_name,$customer_email,$customer_phone,$invoice_unique_id,$due_date,$description,$status,$invoice_items,$tax_info,$total_tax,$discount_info,$total_discount,$subtotal,$grand_total,$paynow_link);



		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('invoice_generate', 'invoice_generate_to_admin_subject');

		$content = self::get_email_template_key_value('invoice_generate', 'invoice_generate_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('invoice_generate', 'invoice_generate_to_customer_subject');

		$content = self::get_email_template_key_value('invoice_generate', 'invoice_generate_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $invoiceid;

		$notificationdata['title'] = esc_html__( 'Invoice generated', 'appointy' );

		$notificationdata['reference'] = 'invoice_generate';

		

		/*Notification send to admin*/

		$description_key = 'invoice_generate_to_admin';

		$description = self::get_notification_template_key_value('invoice_generate',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'invoice__view','invoice_id' => $invoiceid ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		/*Send notification end*/

		

		/*Sms send to customer*/

		$description_key = 'invoice_generate_to_customer';

		$description = self::get_sms_template_key_value('invoice_generate',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('invoice_generate','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('invoice_generate','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				$description_key = 'invoice_generate_to_member';

				$description = self::get_sms_template_key_value('invoice_generate',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('invoice_generate','admin')) {

			$description_key = 'invoice_generate_to_admin';

			$description = self::get_sms_template_key_value('invoice_generate',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}

	

	/**

	 * Send invoice paid email & notification

	 *

	 * @return void

	 */

	public static function send_invoice_paid_email_notifications( $invoiceid = 0 ) {

		$tokens = array('%SITETITLE%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%INVOICEID%','%DUEDATE%','%DESCRIPTION%','%STATUS%','%INVOICE_ITEMS%','%TAX_INFO%','%TAX_AMOUNT%','%DISCOUNT_INFO%','%DISCOUNT_AMOUNT%','%SUBTOTAL%','%GRAND_TOTAL%');

		

		$invoice_object = get_post( $invoiceid );

		

		$customer_name = get_post_meta($invoiceid,'_first_name',true).' '.get_post_meta($invoiceid,'_last_name',true);

		$customer_email = get_post_meta($invoiceid,'_email',true);

		$customer_country_code = get_post_meta($invoiceid,'_country_code',true);

		$customer_phone = get_post_meta($invoiceid,'_phone',true);

		

		$customer_info = get_user_by( 'email', $customer_email );

	

		if(!empty($customer_info)) {

			$customer_user_id = $customer_info->ID;

		} else {

			$customer_user_id = 0;

		}

		

		$due_date = Appointy_Misc_Helper::get_date_format(get_post_meta($invoiceid,'_due_date',true));

		$invoice_unique_id = get_post_meta($invoiceid,'_invoice_id',true);

		

		$description = apply_filters('the_content', $invoice_object->post_content);

		

		$status = Appointy_Appointments_Helper::get_post_status_by_slug( Appointy_Appointments_Helper::get_post_status( $invoiceid ) );

		

		$total_tax = Appointy_Misc_Helper::get_price_format(get_post_meta( $invoiceid,'total_tax',true ));

		$total_discount = Appointy_Misc_Helper::get_price_format(get_post_meta( $invoiceid,'total_discount',true ));

		$subtotal = Appointy_Misc_Helper::get_price_format(get_post_meta( $invoiceid,'subtotal',true ));

		$grand_total = Appointy_Misc_Helper::get_price_format(get_post_meta( $invoiceid,'grand_total',true ));

		

		$invoice_items = Appointy_Invoice_Helper::get_invoice_items($invoiceid);

		$tax_info = Appointy_Invoice_Helper::get_invoice_tax_info($invoiceid);

		$discount_info = Appointy_Invoice_Helper::get_invoice_discount_info($invoiceid);

		

		$replacements = array(get_bloginfo('name'),$customer_name,$customer_email,$customer_phone,$invoice_unique_id,$due_date,$description,$status,$invoice_items,$tax_info,$total_tax,$discount_info,$total_discount,$subtotal,$grand_total);



		/*Send mail start*/

		

		/*Mail send to admin*/

		$subject = self::get_email_template_key_value('invoice_paid', 'invoice_paid_to_admin_subject');

		$content = self::get_email_template_key_value('invoice_paid', 'invoice_paid_to_admin');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( self::get_admin_email(),$subject,$message );

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('invoice_paid', 'invoice_paid_to_customer_subject');

		$content = self::get_email_template_key_value('invoice_paid', 'invoice_paid_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

		/*Send mail end*/

		

		/*Send notification start*/

		

		$notificationdata['reference_id'] = $invoiceid;

		$notificationdata['title'] = esc_html__( 'Invoice paid', 'appointy' );

		$notificationdata['reference'] = 'invoice_paid';

		

		/*Notification send to admin*/

		$description_key = 'invoice_paid_to_admin';

		$description = self::get_notification_template_key_value('invoice_paid',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		$adminlink = add_query_arg( array( 'page' => 'appointment','menu_item' => 'invoice__view','invoice_id' => $invoiceid ), admin_url( 'admin.php' ) );

		

		$notificationdata['key'] = $description_key;

		$notificationdata['link'] = $adminlink;

		$notificationdata['description'] = $description;

		$notificationdata['admin_id'] = 1;

		$notificationdata['customer_id'] = 0;

		

		self::send_notification($notificationdata);

		/*Send notification end*/

		

		/*Sms send to customer*/

		$description_key = 'invoice_paid_to_customer';

		$description = self::get_sms_template_key_value('invoice_paid',$description_key);

		

		$description = str_replace($tokens,$replacements,$description);

		

		if(Appointy_Permission_Helper::has_capability('invoice_paid','customer')) {

		Appointy_Sms_Helper::send_sms($customer_country_code.$customer_phone,$description);

		Appointy_Sms_Helper::send_whatsapp($customer_country_code.$customer_phone,$description);

		}

		

		if($member_id > 0 && Appointy_Permission_Helper::has_capability('invoice_paid','member')) {

			$member_phone = Appointy_Misc_Helper::get_member_phone($member_id);

			if($member_phone != '') {

				$description_key = 'invoice_paid_to_member';

				$description = self::get_sms_template_key_value('invoice_paid',$description_key);

				

				$description = str_replace($tokens,$replacements,$description);

				

				Appointy_Sms_Helper::send_sms($member_phone,$description);

				Appointy_Sms_Helper::send_whatsapp($member_phone,$description);

			}

		}

		

		$admin_phone = Appointy_Misc_Helper::get_admin_phone();

		if($admin_phone != '' && Appointy_Permission_Helper::has_capability('invoice_paid','admin')) {

			$description_key = 'invoice_paid_to_admin';

			$description = self::get_sms_template_key_value('invoice_paid',$description_key);

			

			$description = str_replace($tokens,$replacements,$description);

			

			Appointy_Sms_Helper::send_sms($admin_phone,$description);

			Appointy_Sms_Helper::send_whatsapp($admin_phone,$description);

		}

	}

	

	/**

	 * Send new user email & notification

	 *

	 * @return void

	 */

	public static function send_new_user_email_notifications( $user_id = 0, $password = '' ) {

		$userinfo = get_userdata( $user_id );

		

		$customer_email = Appointy_Router_Helper::get_request_data( $userinfo, 'user_email' );

		$customer_name = Appointy_Router_Helper::get_request_data( $userinfo, 'display_name' );

		

		$country_code = get_user_meta( $user_id,'country_code', true );

		$phone = get_user_meta($user_id, 'phone', true);

		

		$customer_phone = $country_code.''.$phone;

		

		

		$tokens = array('%SITETITLE%','%CUSTOMER_NAME%','%CUSTOMER_EMAIL%','%CUSTOMER_PHONE%','%PASSWORD%');

		

		$replacements = array(get_bloginfo('name'),$customer_name,$customer_email,$customer_phone,$password);

		

		/*Send mail start*/

		

		/*Mail send to customer*/

		$subject = self::get_email_template_key_value('new_user', 'new_user_to_customer_subject');

		$content = self::get_email_template_key_value('new_user', 'new_user_to_customer');

		

		$message = str_replace($tokens,$replacements,$content);

		

		self::send_email( $customer_email,$subject,$message );

	}	

}

new Appointy_Send_Email_Notification_Helper();