<?php 
class Appointy_Staff_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		
		add_action('wp_ajax_save_staff', array($this, 'save_staff'));
		add_action('wp_ajax_get_staff', array($this, 'get_staff'));
		add_action('wp_ajax_load_staff', array($this, 'load_staff'));
		add_action('wp_ajax_appointy_delete_staff', array($this, 'delete_staff'));
		add_action('wp_ajax_save_staff_account', array($this, 'save_staff_account'));
		add_action('wp_ajax_appointy_update_password', array($this, 'update_password'));
    }
	
	/**
	 * Delete staff
	 *
	 * @return array
	 */
	public static function delete_staff() {
		global $wpdb;
		
		$data_ids = Appointy_Router_Helper::get_request_data( $_POST, 'data_ids' );
		
		$data_id_array = explode(",", $data_ids); 

		if(!empty($data_id_array)) {
			foreach($data_id_array as $user_id) {
				wp_delete_user( $user_id );
			}
		}
		
		wp_send_json_success();
		die();
	}
	
	/**
	 * Process load staff
	 *
	 * @return array
	 */
	public static function load_staff( ) {
		global $wpdb;
		
		$staffid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'staffid' );
		
		$staffinfo = get_userdata( $staffid );
		
		$attachment_id = get_user_meta($staffid, $wpdb->get_blog_prefix().'user_avatar', true);
		if($attachment_id > 0) {
			$image_url = Appointy_Image_Helper::get_image_url_by_id($attachment_id);
			$image_tag = '<img src="'.esc_url($image_url).'"/>';
			$image_text = esc_html__( 'Remove','appointy' );
		} else {
			$attachment_id = 0;
			$image_tag = '';
			$image_text = esc_html__( 'Upload Image','appointy' );
		}
		
		
		$response = array( 
			'first_name' => get_user_meta($staffid,'first_name',true),
			'last_name' => get_user_meta($staffid,'last_name',true),
			'username' => Appointy_Router_Helper::get_request_data( $staffinfo, 'user_login' ),
			'email' => Appointy_Router_Helper::get_request_data( $staffinfo, 'user_email' ),
			'phone' => get_user_meta($staffid,'phone',true),
			'image_tag' => $image_tag,
			'image_text' => $image_text,
			'attachment_id' => $attachment_id
		);
		wp_send_json_success($response);
		
   		die();
	}
	
	/**
	 * Get staff
	 *
	 * @return void
	 */
	public static function get_staff() {
	    global $wpdb;
		
		$staffs = get_users( array( 'role__in' => array( 'appointy_staff' ) ) );
		
		$data = array();
		if( !empty( $staffs ) ) {
			$nestedData = array();
			foreach( $staffs as $staff ) {
				$staffid = $staff->ID;
				
				$nestedData['delete'] = '<div class="checkbox sf-radio-checkbox">
											<input type="checkbox" id="staff-'.esc_attr($staffid).'" value="'.esc_attr($staffid).'" class="delete_row delete_staff">
											<label for="staff-'.esc_attr($staffid).'"></label>
										</div>';
				$nestedData['staff_name'] =  $staff->display_name;
				$nestedData['email'] =  $staff->user_email;
				$nestedData['phone'] =  get_user_meta($staffid,'phone',true);
				
				$actions = '<div class="dropdown action-dropdown dropdown-left">
							  <button class="action-button btn btn-primary dropdown-toggle" type="button" data-bs-toggle="dropdown"><i class="fa fa-ellipsis-v"></i></button>
							  <ul class="dropdown-menu">
								<li><a href="javascript:;" class="dropdown-item editstaff" data-staffid="'.esc_attr($staffid).'"><i class="fa fa-pencil"></i> '.esc_html__( 'Edit','appointy' ).'</a></li>
							  </ul>
							</div>';
				
				$nestedData['action'] = $actions;
				
				$data[] = $nestedData;	
			}
		}
		
		$json_data = array( 'data' => $data );
		
		echo json_encode( $json_data );
		die();
	}
	
	/**
     * Save staff
     *
     * @since    1.0.0
     */
    public function save_staff() {
		global $wpdb;
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) || !current_user_can('manage_options') ) {
			wp_send_json_error();
			die();
		}
		
		$attachment_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'image_id' );
		$staffid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'staffid' );
		
		if( !empty( $staffid ) ) {
			$userdata = array(
				'ID'   	  	  =>  $staffid,
				'first_name'  =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'first_name' ),
				'last_name'   =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'last_name' ),
				'user_login'  =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'username' ),
				'user_pass'   =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'password' ),
				'user_email'  =>  Appointy_Router_Helper::get_sanitize_email( $_POST, 'email' ),
				'display_name' =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'first_name' ).' '.Appointy_Router_Helper::get_sanitize_data( $_POST, 'last_name' ),
				'role'   	  =>  'appointy_staff'
			);
			$user_id = wp_update_user( $userdata ) ;		
		} else {
			$userdata = array(
				'first_name'  =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'first_name' ),
				'last_name'   =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'last_name' ),
				'user_login'  =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'username' ),
				'user_pass'   =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'password' ),
				'user_email'  =>  Appointy_Router_Helper::get_sanitize_email( $_POST, 'email' ),
				'role'   	  =>  'appointy_staff'
			);
			$user_id = wp_insert_user( $userdata ) ;
		}
		
   		if ( is_wp_error($user_id) ){
			$response = array('msg' => $user_id->get_error_message());
			wp_send_json_error($response);
	    } else {
			update_user_meta( $user_id,'phone',Appointy_Router_Helper::get_sanitize_data( $_POST, 'phone' ) );
			
			update_post_meta($attachment_id, '_wp_attachment_wp_user_avatar', $user_id);
			update_user_meta($user_id, $wpdb->get_blog_prefix().'user_avatar', $attachment_id);
			
			$response = array('msg' => esc_html__('Staff saved.', 'appointy'));
			
			wp_send_json_success($response);
		
	    }
		
        die();
    }
	
	/**
     * Update Password
     *
     * @since    1.0.0
     */
    public function update_password() {
		global $wpdb;
		if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) ) {
			wp_send_json_error();
			die();
		}
		
		$current_password = Appointy_Router_Helper::get_sanitize_data( $_POST, 'current_password' );
		$password = Appointy_Router_Helper::get_sanitize_data( $_POST, 'password' );
		$confirm_password = Appointy_Router_Helper::get_sanitize_data( $_POST, 'confirm_password' );
		
		$current_user = wp_get_current_user();
		$user_id = $current_user->ID;
		
		$verified = wp_check_password($current_password, $current_user->data->user_pass);
		
		if ($verified && $password === $confirm_password) {
			wp_set_password($password, $user_id);
			
			$creds['user_login'] = ( isset($username) ) ? sanitize_user( $username ) : '';
			$creds['user_password'] = ( isset($password) ) ? $password : '';
			$creds['rememberme'] = true;
			
			$user_id = $current_user->ID;
			$secure_cookie = true;
			wp_set_auth_cookie($user_id, $creds["rememberme"], $secure_cookie);
			wp_set_current_user($user_id);
			
			$response = array('msg' => esc_html__('Password saved.', 'appointy'));
			
			wp_send_json_success($response);	
		} else {
			$response = array('msg' => esc_html__('Incorrect current password.', 'appointy'));
			wp_send_json_error($response);
		}
        die();
    }
	
	/**
     * Save staff account
     *
     * @since    1.0.0
     */
    public function save_staff_account() {
		global $wpdb;
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) ) {
			wp_send_json_error();
			die();
		}
		
		$attachment_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'image_id' );
		$staffid = get_current_user_id();
		
		$userdata = array(
			'ID'   	  	  =>  $staffid,
			'first_name'  =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'first_name' ),
			'last_name'   =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'last_name' ),
			'user_login'  =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'username' ),
			'user_email'  =>  Appointy_Router_Helper::get_sanitize_email( $_POST, 'email' ),
			'display_name' =>  Appointy_Router_Helper::get_sanitize_data( $_POST, 'first_name' ).' '.Appointy_Router_Helper::get_sanitize_data( $_POST, 'last_name' ),
		);
		
		$user_id = wp_update_user( $userdata ) ;
		
   		if ( is_wp_error($user_id) ){
			$response = array('msg' => $user_id->get_error_message());
			wp_send_json_error($response);
	    } else {
			update_user_meta( $user_id,'country_code',Appointy_Router_Helper::get_sanitize_data( $_POST, 'country_code' ) );
			update_user_meta( $user_id,'phone',Appointy_Router_Helper::get_sanitize_data( $_POST, 'phone' ) );
			
			update_user_meta( $user_id,'gender',Appointy_Router_Helper::get_sanitize_data( $_POST, 'gender' ) );
			update_user_meta( $user_id,'address',Appointy_Router_Helper::get_sanitize_data( $_POST, 'address' ) );
			update_user_meta( $user_id,'pincode',Appointy_Router_Helper::get_sanitize_data( $_POST, 'pincode' ) );
			update_user_meta( $user_id,'city',Appointy_Router_Helper::get_sanitize_data( $_POST, 'city' ) );
			
			$response = array('msg' => esc_html__('Information saved.', 'appointy'));
			
			wp_send_json_success($response);
		
	    }
		
        die();
    }
	
	public static function staff_fields( $user_id = 0 ) {
		
		$fields = apply_filters( 'appointy_staff_form_fields', array(
			'first_name' => array(
				'label' => esc_html__( 'First Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-user',
				'colum-width' => 'col-md-6',
				'required'    => true,
				'validation_message' => esc_html__( 'First name is required', 'appointy' ),
				'priority'    => 1
			),
			'last_name' => array(
				'label' => esc_html__( 'Last Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-user',
				'colum-width' => 'col-md-6',
				'required'    => true,
				'validation_message' => esc_html__( 'Last name is required', 'appointy' ),
				'priority'    => 2
			),
			'username' => array(
				'label' => esc_html__( 'Username', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-user',
				'colum-width' => 'col-md-6',
				'required'    => true,
				'validation_message' => esc_html__( 'Username is required', 'appointy' ),
				'priority'    => 3
			),
			'email' => array(
				'label' => esc_html__( 'Email Address', 'appointy' ),
				'type'        => 'email',
				'icon'        => 'fa fa-envelope-o',
				'colum-width' => 'col-md-6',
				'required'    => true,
				'validation_message' => esc_html__( 'Email is required', 'appointy' ),
				'priority'    => 4
			),
			'phone' => array(
				'label'       => esc_html__( 'Contact No', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-phone',
				'colum-width' => 'col-lg-12',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 4
			),
			'password' => array(
				'label' => esc_html__( 'Password', 'appointy' ),
				'type'        => 'password',
				'icon'        => 'fa fa-lock',
				'colum-width' => 'col-md-6',
				'id'          => 'register_password',
				'required'    => true,
				'validation_message' => esc_html__( 'Password is required', 'appointy' ),
				'priority'    => 5
			),
			'cpassword' => array(
				'label' => esc_html__( 'Confirm Password', 'appointy' ),
				'type'        => 'password',
				'equalto'        => 'register_password',
				'icon'        => 'fa fa-lock',
				'colum-width' => 'col-md-6',
				'id'          => 'register_confirm_password',
				'required'    => true,
				'validation_message' => esc_html__( 'Confirm password is required', 'appointy' ),
				'priority'    => 6
			)
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	public static function staff_account_fields( $user_id = 0 ) {
		
		$fields = apply_filters( 'appointy_staff_account_form_fields', array(
			'first_name' => array(
				'label' => esc_html__( 'First Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-user',
				'colum-width' => 'col-xl-4 col-lg-6 col-sm-6',
				'required'    => true,
				'validation_message' => esc_html__( 'First name is required', 'appointy' ),
				'priority'    => 1
			),
			'last_name' => array(
				'label' => esc_html__( 'Last Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-user',
				'colum-width' => 'col-xl-4 col-lg-6 col-sm-6',
				'required'    => true,
				'validation_message' => esc_html__( 'Last name is required', 'appointy' ),
				'priority'    => 2
			),
			'username' => array(
				'label' => esc_html__( 'Username', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-user',
				'colum-width' => 'col-xl-4 col-lg-6 col-sm-6',
				'required'    => true,
				'validation_message' => esc_html__( 'Username is required', 'appointy' ),
				'priority'    => 3
			),
			'email' => array(
				'label' => esc_html__( 'Email Address', 'appointy' ),
				'type'        => 'email',
				'icon'        => 'fa fa-envelope-o',
				'colum-width' => 'col-xl-4 col-lg-6 col-sm-6',
				'required'    => true,
				'validation_message' => esc_html__( 'Email is required', 'appointy' ),
				'priority'    => 4
			),
			'country_code' => array(
				'label'       => esc_html__( 'Country Code', 'appointy' ),
				'type'        => 'select',
				'icon'        => 'feather-map-pin',
				'colum-width' => 'col-xl-4 col-lg-6 col-sm-6',
				'required'    => true,
				'priority'    => 4,
				'options' 	  => Appointy_Sms_Helper::get_country_code_dropdown(),
			),
			'phone' => array(
				'label'       => esc_html__( 'Contact No', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-phone',
				'colum-width' => 'col-xl-4 col-lg-6 col-sm-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 5
			),
			'gender' => array(
				'label'       => esc_html__( 'Gender', 'appointy' ),
				'type'        => 'radio',
				'icon'        => '',
				'colum-width' => 'col-xl-4 col-lg-6 col-sm-6',
				'required'    => false,
				'default'    => 'no',
				'priority'    => 6,
				'options' 	  => array(
									'male' => esc_html__( 'Male', 'appointy' ),
									'female' => esc_html__( 'Female', 'appointy' ),
								)
			),
			'address' => array(
				'label' => esc_html__( 'Street Address', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-xl-6 col-lg-6 col-sm-6',
				'required'    => false,
				'priority'    => 7
			),
			'pincode' => array(
				'label' => esc_html__( 'Pincode', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-info',
				'colum-width' => 'col-xl-3 col-lg-12 col-sm-6',
				'required'    => false,
				'priority'    => 8
			),
			'city' => array(
				'label' => esc_html__( 'City', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-building-o',
				'colum-width' => 'col-lg-3 col-sm-6',
				'required'    => false,
				'priority'    => 9
			),
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	/**
	 * Get user profile picture
	 *
	 * @return array
	 */
	public static function get_user_avatar($user_id = 0,$size = 'healthify-300x300') {
		global $wpdb;
	
		$avatarid = get_user_meta($user_id, $wpdb->get_blog_prefix().'user_avatar', true);
		$src = '';
		if(!empty($avatarid) && $avatarid > 0){
			$src  = wp_get_attachment_image_src( $avatarid, $size );
			$src  = $src[0];
			
			$src = (!empty($src)) ? $src : get_avatar_url($user_id);
		} else {
			$defaultsize = self::get_default_avatar_size($size);
			
			$src = get_avatar_url($user_id,array('size' => $defaultsize));
		}
		
		return $src;
	}
	
	/**
	 * Get default avatar size
	 *
	 * @return array
	 */
	public static function get_default_avatar_size($size = 250) {
		switch($size) {
			case 'healthify-226x304':
				$defaultsize = 226;
				break;	
			case 'healthify-160x160':
				$defaultsize = 162;
				break;	
			case 'healthify-370x252':
				$defaultsize = 370;
				break;	
			case 'healthify-300x300':
				$defaultsize = 300;
				break;	
			case 'healthify-250x250':
				$defaultsize = 250;
				break;
			case 'healthify-600x600':
				$defaultsize = 600;
				break;	
			case 'healthify-700x500':
				$defaultsize = 700;
				break;	
			case 'healthify-800x1000':
				$defaultsize = 800;
				break;	
			case 'healthify-1200x300':
				$defaultsize = 1200;
				break;	
			default:
				$defaultsize = 250;
				break;			
		}
		
		return $defaultsize;
	}
	
	/**
	 * Get member array
	 *
	 * @return void
	 */
	public static function get_member_array() {
	    global $wpdb;
		
		$staffs = get_users( array( 'role' => 'appointy_staff', 'orderby' => 'display_name', 'order' => 'ASC' ) );

		$has_member = false;

		if( !empty($staffs) ) {
			foreach( $staffs as $key => $value ) {
			$staff_id = Appointy_Router_Helper::get_request_data( $value, 'ID' );
			$staff_name = Appointy_Router_Helper::get_request_data( $value, 'display_name' );
			
			$has_member = true;
			$memberarray[$staff_id] = $staff_name;
			}
		}
		
		if( (bool) $has_member === true ) {
			return $memberarray;
		} else {
			$memberarray = array();
			return $memberarray;
		}
	}
}
new Appointy_Staff_Helper();