<?php



/**

 * The public-facing functionality of the plugin.

 *

 * @link       https://aonetheme.com/

 * @since      1.0.0

 *

 * @package    Appointy

 * @subpackage Appointy/public

 */



/**

 * The public-facing functionality of the plugin.

 *

 * Defines the plugin name, version, and two examples hooks for how to

 * enqueue the public-facing stylesheet and JavaScript.

 *

 * @package    Appointy

 * @subpackage Appointy/public

 * @author     Aone Team <aonetheme@gmail.com>

 */

class Appointy_Public {



	/**

	 * The ID of this plugin.

	 *

	 * @since    1.0.0

	 * @access   private

	 * @var      string    $plugin_name    The ID of this plugin.

	 */

	private $plugin_name;



	/**

	 * The version of this plugin.

	 *

	 * @since    1.0.0

	 * @access   private

	 * @var      string    $version    The current version of this plugin.

	 */

	private $version;



	/**

	 * Initialize the class and set its properties.

	 *

	 * @since    1.0.0

	 * @param      string    $plugin_name       The name of the plugin.

	 * @param      string    $version    The version of this plugin.

	 */

	public function __construct( $plugin_name, $version ) {



		$this->plugin_name = $plugin_name;

		$this->version = $version;



	}



	/**

	 * Register the stylesheets for the public-facing side of the site.

	 *

	 * @since    1.0.0

	 */

	public function enqueue_styles() {



		/**

		 * This function is provided for demonstration purposes only.

		 *

		 * An instance of this class should be passed to the run() function

		 * defined in Appointy_Loader as all of the hooks are defined

		 * in that particular class.

		 *

		 * The Appointy_Loader will then create the relationship

		 * between the defined hooks and the functions defined in this

		 * class.

		 */

		

		if(Appointy_Misc_Helper::has_appointy_shortcode()) {

		Appointy_Misc_Helper::dynamic_style();

		

		wp_register_style( 'smartwizard', plugin_dir_url( __FILE__ ) . 'css/smart_wizard_all.css', array(), '6.0.5', 'all' );

		

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/appointy-public.css', array(), $this->version, 'all' );

		

		}



	}



	/**

	 * Register the JavaScript for the public-facing side of the site.

	 *

	 * @since    1.0.0

	 */

	public function enqueue_scripts() {



		/**

		 * This function is provided for demonstration purposes only.

		 *

		 * An instance of this class should be passed to the run() function

		 * defined in Appointy_Loader as all of the hooks are defined

		 * in that particular class.

		 *

		 * The Appointy_Loader will then create the relationship

		 * between the defined hooks and the functions defined in this

		 * class.

		 */



		if(Appointy_Misc_Helper::has_appointy_shortcode()) {

		$jsurl = ( is_ssl() ? 'https:' : 'http:' ) . '//cdn.datatables.net/1.12.1/js/jquery.dataTables.min.js';

		$cssurl = ( is_ssl() ? 'https:' : 'http:' ) . '//cdn.datatables.net/1.12.1/css/jquery.dataTables.min.css';

		

		$jsresponse = wp_remote_head($jsurl);

	

		// Load local file if CDN down

		if ( is_wp_error($jsresponse) || 200 != $jsresponse['response']['code'] ) {

	

			$jsurl = APPOINTY_PLUGIN_URL . 'assets/js/jquery.dataTables.min.js';

		}

		

		$cssresponse = wp_remote_head($cssurl);

		

		if ( is_wp_error($cssresponse) || 200 != $cssresponse['response']['code'] ) {

	

			$cssurl = APPOINTY_PLUGIN_URL . 'assets/css/jquery.dataTables.min.css';

		}

		$locale = substr(get_locale(), 0, 2);

		$locale_full = get_locale();

		

		wp_register_script('datatables', $jsurl, [ 'jquery' ] , null, true);

		wp_register_style('datatables', $cssurl,'',null);

		

		$jsurl = ( is_ssl() ? 'https:' : 'http:' ) . '//cdn.datatables.net/1.12.1/js/dataTables.bootstrap5.min.js';

		$cssurl = ( is_ssl() ? 'https:' : 'http:' ) . '//cdn.datatables.net/1.12.1/css/dataTables.bootstrap5.min.css';

		

		$jsresponse = wp_remote_head($jsurl);

	

		// Load local file if CDN down

		if ( is_wp_error($jsresponse) || 200 != $jsresponse['response']['code'] ) {

	

			$jsurl = APPOINTY_PLUGIN_URL . 'assets/js/dataTables.bootstrap5.min.js';

		}

		

		$cssresponse = wp_remote_head($cssurl);

		

		if ( is_wp_error($cssresponse) || 200 != $cssresponse['response']['code'] ) {

	

			$cssurl = APPOINTY_PLUGIN_URL . 'assets/css/dataTables.bootstrap5.min.css';

		}

		

		wp_register_style('bootstrap-datatable', $cssurl,'',null);

		wp_register_script('bootstrap-datatable', $jsurl, [ 'jquery','datatables' ] , null, true);

		

		wp_register_script( 'popper', APPOINTY_PLUGIN_URL . 'assets/js/popper.min.js', ['jquery'], false, true );

		

		wp_register_style( 'bootstrap', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap.min.css', [], false, 'all' );

		wp_register_script( 'bootstrap', APPOINTY_PLUGIN_URL . 'assets/js/bootstrap.min.js', ['jquery','popper'], '5.2.1', true ); 

		

		wp_register_style( 'bootstrap-toggle', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap4-toggle.min.css', [], false, 'all' );

		wp_register_script( 'bootstrap-toggle', APPOINTY_PLUGIN_URL . 'assets/js/bootstrap4-toggle.min.js', ['jquery'], false, true );

		

		wp_register_style( 'font-awesome', APPOINTY_PLUGIN_URL . 'assets/css/font-awesome.min.css', [], false, 'all' );

		

		wp_enqueue_style( 'appointy-gfonts', $this->fonts_url(), [], false, 'all' );

		

		wp_enqueue_style( 'feather', APPOINTY_PLUGIN_URL . 'assets/css/feather.css', [], false, 'all' );

		

		wp_register_style( 'fullcalendar-main', APPOINTY_PLUGIN_URL . 'assets/fullcalendar/main.min.css', '', null );

		wp_register_script( 'fullcalendar-main', APPOINTY_PLUGIN_URL . 'assets/fullcalendar/main.min.js', [ 'jquery' ], '5.11.2', true );

		wp_register_script( 'fullcalendar-locales', APPOINTY_PLUGIN_URL . 'assets/fullcalendar/locales-all.min.js', [ 'jquery' ], '5.11.2', true );

		

		wp_enqueue_script('bootbox', APPOINTY_PLUGIN_URL . 'assets/js/bootbox.min.js', [ 'jquery' ] , '5.5.2', true);

		wp_enqueue_script('bootbox-locales',  APPOINTY_PLUGIN_URL . 'assets/js/bootbox.locales.min.js', [ 'jquery' ] , '5.5.2', true);

		

		wp_register_style( 'bootstrap-datepicker', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap-datepicker.min.css', '', null );

		wp_register_script( 'bootstrap-datepicker', APPOINTY_PLUGIN_URL . 'assets/js/datepicker/bootstrap-datepicker.min.js', [ 'jquery' ], '1.9.0', true );

		wp_register_script('bootstrap-datepicker-'.$locale, APPOINTY_PLUGIN_URL . 'assets/js/datepicker/locales/bootstrap-datepicker.'.$locale.'.js', [ 'jquery' ], '1.9.0', true );

		

		wp_enqueue_script( 'jquery-validate', APPOINTY_PLUGIN_URL . 'assets/js/dist/jquery.validate.min.js', [ 'jquery' ], '1.19.3', true );

		

		// Time picker scripts

		wp_enqueue_style('bootstrap-datetimepicker', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap-datetimepicker.min.css','',null);

		wp_enqueue_script('moment-with-locales', APPOINTY_PLUGIN_URL . 'assets/js/moment-with-locales.js', [ 'jquery' ] , null, true);

		wp_enqueue_script('bootstrap-datetimepicker', APPOINTY_PLUGIN_URL . 'assets/js/bootstrap-datetimepicker.min.js', [ 'jquery' ] , '4.17.47', true);

		

		wp_enqueue_script('jRate',  APPOINTY_PLUGIN_URL . 'assets/js/jRate.js', [ 'jquery' ] , null, true);

		

		wp_register_style('daterangepicker', APPOINTY_PLUGIN_URL . 'assets/css/daterangepicker.css','',null);

		wp_register_script('daterangepicker', APPOINTY_PLUGIN_URL . 'assets/js/daterangepicker.js', [ 'jquery' ] , '3.1', true);

		

		wp_register_style('owl-carousel', APPOINTY_PLUGIN_URL . 'assets/css/owl.carousel.min.css','',null);

		wp_register_script('owl-carousel', APPOINTY_PLUGIN_URL . 'assets/js/owl.carousel.min.js', [ 'jquery' ] , '3.1', true);

		

		wp_register_script( 'jquery-validate', APPOINTY_PLUGIN_URL . 'assets/js/dist/jquery.validate.min.js', [ 'jquery' ], '1.19.5', true );

		

		wp_enqueue_script( 'bootstrap-datepicker' );

		if( 'en' != $locale ) {



			wp_enqueue_script( 'bootstrap-datepicker-'.$locale );

		}

		wp_enqueue_style( 'bootstrap-datepicker' );

		

		wp_enqueue_script('popper');

		wp_enqueue_style( 'bootstrap-toggle' );

		wp_enqueue_script( 'bootstrap-toggle' );

		wp_enqueue_style('bootstrap');

		wp_enqueue_script('bootstrap');

		wp_enqueue_style('font-awesome');

		

		wp_register_script( 'smartwizard', plugin_dir_url( __FILE__ ) . 'js/jquery.smartWizard.js', array( 'jquery' ), '6.0.5', false );

		

		wp_register_script( 'plupload', plugin_dir_url( __FILE__ ) . 'js/plupload.full.min.js', [ 'jquery' ] , '1.5.8', true);

		wp_register_script( 'appointy-upload-files', plugin_dir_url( __FILE__ ) . 'js/upload-files.js', array( 'jquery','bootstrap' ), rand(), false );

		wp_register_script( 'appointy-image-manager', plugin_dir_url( __FILE__ ) . 'js/image-manager.js', array( 'jquery','bootstrap' ), rand(), false );

		

		if(Appointy_Router_Helper::trafic_jammer() === true) {

		if(APPOINTY_BOOKING_TYPE === 'hotel') {

		wp_register_script( 'appointy-booking-form', plugin_dir_url( __FILE__ ) . 'js/appointy-hotel-booking-form.js', array( 'jquery','bootstrap' ), rand(), false );

		wp_register_script( 'appointy-single-hotel-booking-form', plugin_dir_url( __FILE__ ) . 'js/appointy-single-hotel-booking-form.js', array( 'jquery','bootstrap' ), rand(), false );

		}else{

		wp_register_script( 'appointy-booking-form', plugin_dir_url( __FILE__ ) . 'js/appointy-booking-form.js', array( 'jquery','bootstrap' ), rand(), false );

		}

		}

		

		wp_register_script( 'appointy-payment', plugin_dir_url( __FILE__ ) . 'js/appointy-payment.js', array( 'jquery' ), $this->version, false );

		wp_register_script( 'appointy-login', plugin_dir_url( __FILE__ ) . 'js/appointy-login.js', array( 'jquery' ), $this->version, false );

		

		wp_register_style( 'appointy-dashboard', plugin_dir_url( __FILE__ ) . 'css/appointy-dashboard.css', [], false, 'all' );

		wp_register_script( 'jRate', plugin_dir_url( __FILE__ ) . 'js/jRate.js', array( 'jquery' ), $this->version, false );

		wp_register_script( 'appointy-dashboard', plugin_dir_url( __FILE__ ) . 'js/appointy-dashboard.js', array( 'jquery' ), $this->version, false );

		wp_register_script( 'appointy-staff-availability', plugin_dir_url( __FILE__ ) . 'js/appointy-staff-availability.js', array( 'jquery' ), $this->version, false );

		

		$cart_url = (class_exists( 'WooCommerce' ) && !is_admin()) ? wc_get_checkout_url() : '';

		

		$appointy_options = array(

			'ajaxurl' => admin_url( 'admin-ajax.php' ),

			'cart_url' => $cart_url,

			'home_url' => esc_url( home_url( '/' ) ),

			'_nonce' => wp_create_nonce( 'appointy_ajax_nonce' ),

			'not_avl' => esc_html__( 'Not available', 'appointy' ),

			'image_text' => esc_html__( 'Upload Image','appointy' ),

			'dateformat' => Appointy_Misc_Helper::datepicker_format(),

			'timezone' => wp_timezone_string(),

			'default_country_code' => Appointy_Location_Helper::get_default_country_code(),

			'default_country' => Appointy_Location_Helper::get_default_country(),

			'default_state' => Appointy_Location_Helper::get_default_state(),

			'are_you_sure' => esc_html__( 'Are you sure?', 'appointy' ),

			'select_checkbox' => esc_html__( 'Please select atleast one checkbox', 'appointy' ),

			'sEmptyTable' => esc_html__( 'No data available in table', 'appointy' ),

			'sInfo' => esc_html__( 'Showing _START_ to _END_ of _TOTAL_ entries', 'appointy' ),

			'sInfoEmpty' => esc_html__( 'Showing 0 to 0 of 0 entries', 'appointy' ),

			'sInfoFiltered' => esc_html__( '(filtered from _MAX_ total entries)', 'appointy' ),

			'sLengthMenu' => esc_html__( 'Show _MENU_ entries', 'appointy' ),

			'sLoadingRecords' => esc_html__( 'Loading...', 'appointy' ),

			'sProcessing' => esc_html__( 'Processing...', 'appointy' ),

			'sSearch' => esc_html__( 'Search:', 'appointy' ),

			'sZeroRecords' => esc_html__( 'No matching records found', 'appointy' ),

			'sFirst' => esc_html__( 'First', 'appointy' ),

			'sLast' => esc_html__( 'Last', 'appointy' ),

			'sNext' => esc_html__( 'Next', 'appointy' ),

			'sPrevious' => esc_html__( 'Previous', 'appointy' ),

			'sSortAscending' => esc_html__( ': activate to sort column ascending', 'appointy' ),

			'sSortDescending' => esc_html__( ': activate to sort column descending', 'appointy' ),

			'sSortDescending' => esc_html__( ': activate to sort column descending', 'appointy' ),

			'minutes' => esc_html__( 'Minutes', 'appointy' ),

			'hours' => esc_html__( 'Hours', 'appointy' ),

			'price' => esc_html__( 'Price', 'appointy' ),

			'duration' => esc_html__( 'Duration', 'appointy' ),

			'service_name' => (APPOINTY_BOOKING_TYPE == 'hotel') ? esc_html__( 'Room Name', 'appointy' ) : esc_html__( 'Service Name', 'appointy' ),

			'currency_symbol' => Appointy_Misc_Helper::get_currency_symbol(),

			'add_sale_price' => esc_html__( 'Please insert sale price', 'appointy' ),

			'add_regular_price' => esc_html__( 'Please insert regular price', 'appointy' ),

			'inert_veriation_name' => esc_html__( 'Please insert service veriation name', 'appointy' ),

			'date_n_time_required' => esc_html__( 'Please select appointment date & time by click on manage date & time button', 'appointy' ),

			'minutes_short' => esc_html__( 'Mins', 'appointy' ),

			'start_str' => esc_html__( 'Start', 'appointy' ),

			'end_str' => esc_html__( 'End', 'appointy' ),

			'select_startendtime' => esc_html__( 'Please select start and endtime', 'appointy' ),

			'endtime_greater_than_starttime' => esc_html__( 'End time should be greater than start time', 'appointy' ),

			'select_interval' => esc_html__( 'Please select interval', 'appointy' ),

			'start_date' => esc_html__( 'Start Date', 'appointy' ),

			'end_date' => esc_html__( 'End Date', 'appointy' ),

			'to' => esc_html__( 'to', 'appointy' ),

			'timeslot_exist' => esc_html__( 'This timeslot already taken.', 'appointy' ),

			'select_location_validate' => esc_html__( 'Please select location.', 'appointy' ),

			'select_date_validate' => esc_html__( 'Please select date.', 'appointy' ),

			'select_time_validate' => esc_html__( 'Please select time slot.', 'appointy' ),

			'have_couponcode' => esc_html__( 'Do You Have Coupon Code?', 'appointy' ),

			'couponcode_applied' => esc_html__( 'Coupon Code applied successfully', 'appointy' ),

			'enter_couponcode' => esc_html__( 'Please enter coupon code', 'appointy' ),

			'total' => esc_html__( 'Total', 'appointy' ),

			'total_service_amount' => (APPOINTY_BOOKING_TYPE == 'hotel') ? esc_html__( 'Total Amount', 'appointy' ) : esc_html__( 'Total Service Amount', 'appointy' ),

			'gift_voucher_label' => esc_html__( 'Gift Voucher', 'appointy' ),

			'select_service_validate' => (APPOINTY_BOOKING_TYPE == 'hotel') ? esc_html__( 'Please select room.', 'appointy' ) : esc_html__( 'Please select service.', 'appointy' ),

			'enter_couponcode' => esc_html__( 'Please enter coupon code', 'appointy' ),

			'enter_voucher_info' => esc_html__( 'Please enter voucher number and pin', 'appointy' ),

			'validate_staff_member' => esc_html__( 'Please select staff member', 'appointy' ),

			'text_edit_staff' => esc_html__( 'Edit Member', 'appointy' ),

			'text_assign_staff' => esc_html__( 'Assign to the Member', 'appointy' ),

			'continue_to_customer' => esc_html__( 'Continue', 'appointy' ),

			'back_to_services' => (APPOINTY_BOOKING_TYPE == 'hotel') ? esc_html__( 'Back to Rooms', 'appointy' ) : esc_html__( 'Back to Services', 'appointy' ),

			'view_more' => esc_html__( 'View Summary', 'appointy' ),

			'total_value' => esc_html__( 'Total Value', 'appointy' ),

			'proceed_to_pay' => (Appointy_Misc_Helper::get_settings( 'booking_settings', 'payment_mode' ) === 'online') ? esc_html__( 'Proceed to Pay', 'appointy' ) : esc_html__( 'Proceed to Checkout', 'appointy' ),

			'current_password_req' => esc_html__( 'Current password is required', 'appointy' ),

			'password_req' => esc_html__( 'Password is required', 'appointy' ),

			'confirm_password_req' => esc_html__( 'Confirm password not matched with password', 'appointy' ),

			'booking_review_details' => esc_html__( 'Review Details', 'appointy' ),

			'maxFileUploadsSingle' => esc_html__( 'You may only upload maximum %d file', 'appointy' ),

			'maxFileUploadsPlural' => esc_html__( 'You may only upload maximum %d files', 'appointy' ),

			'image_url' => APPOINTY_IMAGE_URL,

			'fetching_events_error' => esc_html__( 'There was an error while fetching events!', 'appointy' ),

			'select_duration' => esc_html__( 'Please select duration', 'appointy' ),

			'locale' => $locale,

			'locale_full' => str_replace('_','-',$locale_full),

			'time_format' => (get_option( 'time_format' ) === 'H:i') ? 'HH:mm' : 'LT',

			'paymentmode' => Appointy_Misc_Helper::get_settings( 'booking_settings', 'payment_mode' ),

			'deposit_options' => Appointy_Misc_Helper::get_settings( 'booking_settings', 'deposit_options', 'full_payment' ),

			'deposit_amount' => Appointy_Misc_Helper::get_settings( 'booking_settings', 'deposit_amount', 10 ),

			'deposit_type' => Appointy_Misc_Helper::get_settings( 'booking_settings', 'deposit_type', 'percent' ),

			'pay' => esc_html__( 'Pay', 'appointy' ),

			'due' => esc_html__( 'Due', 'appointy' ),

			'January' => esc_html__( 'January', 'appointy' ),

			'February' => esc_html__( 'February', 'appointy' ),

			'March' => esc_html__( 'March', 'appointy' ),

			'April' => esc_html__( 'April', 'appointy' ),

			'May' => esc_html__( 'May', 'appointy' ),

			'June' => esc_html__( 'June', 'appointy' ),

			'July' => esc_html__( 'July', 'appointy' ),

			'August' => esc_html__( 'August', 'appointy' ),

			'September' => esc_html__( 'September', 'appointy' ),

			'October' => esc_html__( 'October', 'appointy' ),

			'November' => esc_html__( 'November', 'appointy' ),

			'December' => esc_html__( 'December', 'appointy' ),

			'Monday' => esc_html__( 'Monday', 'appointy' ),

			'Tuesday' => esc_html__( 'Tuesday', 'appointy' ),

			'Wednesday' => esc_html__( 'Wednesday', 'appointy' ),

			'Thursday' => esc_html__( 'Thursday', 'appointy' ),

			'Friday' => esc_html__( 'Friday', 'appointy' ),

			'Saturday' => esc_html__( 'Saturday', 'appointy' ),

			'Sunday' => esc_html__( 'Sunday', 'appointy' ),

			'Date: N/A' => esc_html__( 'Date: N/A', 'appointy' ),

			'Weekday: N/A' => esc_html__( 'Weekday: N/A', 'appointy' ),

			'Time: N/A' => esc_html__( 'Time: N/A', 'appointy' ),

			'repeat_appointment' => esc_html__( 'Repeat Appointment', 'appointy' ),

			'enter_times' => esc_html__( 'Enter enter number of times', 'appointy' ),

			'select_frequency' => esc_html__( 'Please select frequency', 'appointy' ),

			'select_weekday' => esc_html__( 'Please select weekday', 'appointy' ),

			'select_day_of_month' => esc_html__( 'Please select day of month', 'appointy' ),

			'extra_services' => (APPOINTY_BOOKING_TYPE == 'hotel') ? esc_html__( 'Extras', 'appointy' ) : esc_html__( 'Extra Services', 'appointy' ),

			'dates' => esc_html__( 'Dates', 'appointy' ),

			'select_avl_dates' => esc_html__( 'Please select only avaialble dates.', 'appointy' ),

			'select_starttime' => esc_html__( 'Please select start time', 'appointy' ),

			'booking_type' => Appointy_Misc_Helper::get_settings( 'booking_settings', 'booking_type', 'general' ),

			'rooms_label' => esc_html__( 'Rooms', 'appointy' ),

			'adults_label' => esc_html__( 'Adults', 'appointy' ),

			'children_label' => esc_html__( 'Children', 'appointy' ),

			'enter_checkin_out_date' => esc_html__( 'Please enter check in and check out date', 'appointy' ),

			'room_not_suit_requirement' => esc_html__( 'This room is not suitable accroding to your requirement. Still you want to book?', 'appointy' ),

		);

		

		wp_localize_script( 'appointy-booking-form', 'appointy_options', $appointy_options);

		wp_localize_script( 'appointy-single-hotel-booking-form', 'appointy_options', $appointy_options);

		wp_localize_script( 'appointy-payment', 'appointy_options', $appointy_options);

		wp_localize_script( 'appointy-login', 'appointy_options', $appointy_options);

		wp_localize_script( 'appointy-dashboard', 'appointy_options', $appointy_options);

		wp_localize_script( 'appointy-staff-availability', 'appointy_options', $appointy_options);

		wp_localize_script( 'appointy-upload-files', 'appointy_options', $appointy_options);

		wp_localize_script( 'appointy-image-manager', 'appointy_options', $appointy_options);

		}

	}

	

	public function fonts_url() {

		$fonts_url = '';

		

		if ( 'off' !== _x( 'on', 'Google font: on or off', 'appointy' ) ) {



			$Poppins = _x( 'on', 'Poppins font: on or off', 'appointy' );

			

			if ( 'off' !== $Poppins ) {

				$font_families = array();

				 

				if ( 'off' !== $Poppins ) {

				$font_families[] = 'Poppins:wght@300,400,500,600,700,800,900';

				}

				 

				$final_fonts = array_unique( $font_families );

				$query_args  = [

					'family'  => urlencode( implode( '|', $final_fonts ) ),

					'display' => urlencode( 'swap' ),

				];

	

				$fonts_url = add_query_arg( $query_args, "//fonts.googleapis.com/css" );

			}



		}

		

		return esc_url_raw( $fonts_url );

	}

	

	/**

	 * Call upload form shortcode

	 *

	 * @since    1.0.0

	 */

	function appointy_upload( $atts ) {

		ob_start();

		Appointy_Template_Loader::get_template_part( 'uploader/index', $atts );



		return ob_get_clean();

	}

	

	/**

	 * Call booking form shortcode

	 *

	 * @since    1.0.0

	 */

	function appointy_booking_form( $atts ) {

		wp_enqueue_script( 'jRate' );

		wp_enqueue_style( 'owl-carousel' );

		wp_enqueue_script( 'owl-carousel' );

		wp_enqueue_script( 'appointy-booking-form' );

		

		$alltaxes = Appointy_Tax_Helper::get_all_taxes();

		$alltaxes = wp_json_encode($alltaxes);

		$taxdata = 'var taxdata = '.$alltaxes.';';

		wp_add_inline_script('appointy-booking-form', $taxdata, 'before');

		

		$couponcode_for = Appointy_Misc_Helper::get_settings( 'booking_settings', 'coupon_code_for' );

		$couponcode = (Appointy_Misc_Helper::get_settings( 'booking_settings', 'booking_coupon_code' )) ? 'yes' : 'no';

		$jsdata = 'var jsdata = { 

				"booking_couponcode": "'.$couponcode.'", 

				"couponcode_for": "'.$couponcode_for.'"

				};';

		wp_add_inline_script('appointy-booking-form', $jsdata, 'before');

		ob_start();

		

		if(APPOINTY_BOOKING_TYPE == 'hotel') {

			Appointy_Template_Loader::get_template_part( 'booking/hotel-booking-form' );

		}else{

			Appointy_Template_Loader::get_template_part( 'booking/booking-form' );

		}

		



		return ob_get_clean();

	}

	

	/**

	 * Call booking form shortcode for single hotel room

	 *

	 * @since    1.0.0

	 */

	function appointy_hotel_booking_form( $atts ) {

		wp_enqueue_script( 'appointy-single-hotel-booking-form' );

		

		$alltaxes = Appointy_Tax_Helper::get_all_taxes();

		$alltaxes = wp_json_encode($alltaxes);

		$taxdata = 'var taxdata = '.$alltaxes.';';

		wp_add_inline_script('appointy-single-hotel-booking-form', $taxdata, 'before');

		

		$couponcode_for = Appointy_Misc_Helper::get_settings( 'booking_settings', 'coupon_code_for' );

		$couponcode = (Appointy_Misc_Helper::get_settings( 'booking_settings', 'booking_coupon_code' )) ? 'yes' : 'no';

		$jsdata = 'var jsdata = { 

				"booking_couponcode": "'.$couponcode.'", 

				"couponcode_for": "'.$couponcode_for.'"

				};';

		wp_add_inline_script('appointy-booking-form', $jsdata, 'before');

		ob_start();

		

		Appointy_Template_Loader::get_template_part( 'booking/single-hotel-booking-form' );

		

		return ob_get_clean();

	}
	
	/**

	 * Call check availability form shortcode for single hotel room

	 *

	 * @since    1.0.0

	 */

	function appointy_hotel_check_availability_form( $atts ) {

		wp_enqueue_script( 'appointy-single-hotel-booking-form' );

		

		$alltaxes = Appointy_Tax_Helper::get_all_taxes();

		$alltaxes = wp_json_encode($alltaxes);

		$taxdata = 'var taxdata = '.$alltaxes.';';

		wp_add_inline_script('appointy-single-hotel-booking-form', $taxdata, 'before');

		

		$couponcode_for = Appointy_Misc_Helper::get_settings( 'booking_settings', 'coupon_code_for' );

		$couponcode = (Appointy_Misc_Helper::get_settings( 'booking_settings', 'booking_coupon_code' )) ? 'yes' : 'no';

		$jsdata = 'var jsdata = { 

				"booking_couponcode": "'.$couponcode.'", 

				"couponcode_for": "'.$couponcode_for.'"

				};';

		wp_add_inline_script('appointy-booking-form', $jsdata, 'before');

		ob_start();

		

		Appointy_Template_Loader::get_template_part( 'booking/hotel-check-availability-form' );

		

		return ob_get_clean();

	}

	

	/**

	 * Call giftcard payment shortcode

	 *

	 * @since    1.0.0

	 */

	function appointy_giftcard_payment( $atts ) {

		wp_enqueue_style( 'smartwizard' );

		wp_enqueue_script( 'smartwizard' );

		wp_enqueue_script( 'appointy-payment' );

		

		ob_start();



		Appointy_Template_Loader::get_template_part( 'giftcard/buy-giftcard' );



		return ob_get_clean();

	}

	

	/**

	 * Call repeat service payment

	 *

	 * @since    1.0.0

	 */

	function appointy_repeat_service_payment( $atts ) {

		wp_enqueue_script( 'appointy-payment' );

		

		ob_start();



		Appointy_Template_Loader::get_template_part( 'repeatpayment/repeat-payment' );



		return ob_get_clean();

	}

	

	/**

	 * Call invoice payment shortcode

	 *

	 * @since    1.0.0

	 */

	function appointy_invoice_payment( $atts ) {

		wp_enqueue_script( 'appointy-payment' );

		

		ob_start();



		Appointy_Template_Loader::get_template_part( 'invoice/invoice-payment' );



		return ob_get_clean();

	}

	

	/**

	 * Call thank you page shortcode

	 *

	 * @since    1.0.0

	 */

	function appointy_thank_you( $atts ) {

		wp_enqueue_script( 'appointy-payment' );

		

		ob_start();



		Appointy_Template_Loader::get_template_part( 'thank-you/index' );



		return ob_get_clean();

	}

	

	/**

	 * Call login page shortcode

	 *

	 * @since    1.0.0

	 */

	function appointy_login( $atts ) {

		wp_enqueue_script( 'appointy-login' );

		

		ob_start();



		Appointy_Template_Loader::get_template_part( 'login/index' );



		return ob_get_clean();

	}

	

	/**

	 * Call staff dashboard page shortcode

	 *

	 * @since    1.0.0

	 */

	function appointy_staff_dashboard( $atts ) {

		wp_enqueue_script( 'jRate' );

		wp_enqueue_style( 'appointy-dashboard' );

		wp_enqueue_script( 'appointy-dashboard' );

		

		ob_start();



		Appointy_Template_Loader::get_template_part( 'staff-dashboard/index' );



		return ob_get_clean();

	}

	

	/**

	 * Call customer dashboard page shortcode

	 *

	 * @since    1.0.0

	 */

	function appointy_customer_dashboard( $atts ) {

		wp_enqueue_style( 'appointy-dashboard' );

		wp_enqueue_script( 'appointy-dashboard' );

		

		ob_start();



		Appointy_Template_Loader::get_template_part( 'customer-dashboard/index' );



		return ob_get_clean();

	}

	

	/**

	 * Alerts messages html in footer

	 *

	 * @return void

	 */

	public function alerts_html_to_footer() {

		Appointy_Template_Loader::get_template_part( 'alert-message' );

	}

}

